@@ -5,7 +5,7 @@
  * Generic transliteration data for the PhpTransliteration class.
  */
 
-$base = array(
+$base = [
   // Note: to save memory plain ASCII mappings have been left out.
   0x80 => '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '',
   0x90 => '', '', '', '', '', '', '', '', '', '', '', '', '', '', '', '',
@@ -15,4 +15,4 @@ $base = array(
   0xD0 => 'D', 'N', 'O', 'O', 'O', 'O', 'O', '*', 'O', 'U', 'U', 'U', 'U', 'Y', 'TH', 'ss',
   0xE0 => 'a', 'a', 'a', 'a', 'a', 'a', 'ae', 'c', 'e', 'e', 'e', 'e', 'i', 'i', 'i', 'i',
   0xF0 => 'd', 'n', 'o', 'o', 'o', 'o', 'o', '/', 'o', 'u', 'u', 'u', 'u', 'y', 'th', 'y',
-);
+];
