@@ -140,9 +140,11 @@ class ConfigInstaller implements ConfigInstallerInterface {
     }
 
     // During a drupal installation optional configuration is installed at the
-    // end of the installation process.
+    // end of the installation process. Once the install profile is installed
+    // optional configuration should be installed as usual.
     // @see install_install_profile()
-    if (!$this->isSyncing() && !InstallerKernel::installationAttempted()) {
+    $profile_installed = in_array($this->drupalGetProfile(), $this->getEnabledExtensions(), TRUE);
+    if (!$this->isSyncing() && (!InstallerKernel::installationAttempted() || $profile_installed)) {
       $optional_install_path = $extension_path . '/' . InstallStorage::CONFIG_OPTIONAL_DIRECTORY;
       if (is_dir($optional_install_path)) {
         // Install any optional config the module provides.
@@ -619,6 +621,7 @@ class ConfigInstaller implements ConfigInstallerInterface {
           case 'theme':
             $list_to_check = $enabled_extensions;
             break;
+
           case 'config':
             $list_to_check = $all_config;
             break;
@@ -724,22 +727,4 @@ class ConfigInstaller implements ConfigInstallerInterface {
     return $this->installProfile;
   }
 
-  /**
-   * Wrapper for drupal_installation_attempted().
-   *
-   * @return bool
-   *   TRUE if a Drupal installation is currently being attempted.
-   *
-   * @deprecated in drupal:8.8.0 and is removed from drupal:9.0.0.
-   *   Use \Drupal\Core\Installer\InstallerKernel::installationAttempted()
-   *   instead.
-   *
-   * @see https://www.drupal.org/node/3052704
-   * @see \Drupal\Core\Installer\InstallerKernel::installationAttempted()
-   */
-  protected function drupalInstallationAttempted() {
-    @trigger_error(__METHOD__ . '() is deprecated in drupal:8.8.0 and is removed from drupal:9.0.0. Use \Drupal\Core\Installer\InstallerKernel::installationAttempted() instead. See https://www.drupal.org/node/3052704', E_USER_DEPRECATED);
-    return InstallerKernel::installationAttempted();
-  }
-
 }
