@@ -65,7 +65,7 @@ class Update extends Query implements ConditionInterface {
     parent::__construct($connection, $options);
     $this->table = $table;
 
-    $this->condition = new Condition('AND');
+    $this->condition = $this->connection->condition('AND');
   }
 
   /**
