@@ -64,22 +64,6 @@ abstract class EntityBase implements EntityInterface {
     }
   }
 
-  /**
-   * Gets the entity manager.
-   *
-   * @return \Drupal\Core\Entity\EntityManagerInterface
-   *
-   * @deprecated in Drupal 8.0.0 and will be removed before Drupal 9.0.0.
-   *   Use \Drupal::entityTypeManager() instead in most cases. If the needed
-   *   method is not on \Drupal\Core\Entity\EntityTypeManagerInterface, see the
-   *   deprecated \Drupal\Core\Entity\EntityManager to find the
-   *   correct interface or service.
-   */
-  protected function entityManager() {
-    @trigger_error('Entity::getEntityManager() is deprecated in Drupal 8.7.0 and will be removed before Drupal 9.0.0. Use ::getEntityTypeManager() instead. See https://www.drupal.org/node/2549139.', E_USER_DEPRECATED);
-    return \Drupal::entityManager();
-  }
-
   /**
    * Gets the entity type manager.
    *
@@ -164,23 +148,9 @@ abstract class EntityBase implements EntityInterface {
    * {@inheritdoc}
    */
   public function label() {
-    $label = NULL;
-    $entity_type = $this->getEntityType();
-    if (($label_callback = $entity_type->getLabelCallback()) && is_callable($label_callback)) {
-      $label = call_user_func($label_callback, $this);
+    if (($label_key = $this->getEntityType()->getKey('label')) && isset($this->{$label_key})) {
+      return $this->{$label_key};
     }
-    elseif (($label_key = $entity_type->getKey('label')) && isset($this->{$label_key})) {
-      $label = $this->{$label_key};
-    }
-    return $label;
-  }
-
-  /**
-   * {@inheritdoc}
-   */
-  public function urlInfo($rel = 'canonical', array $options = []) {
-    @trigger_error('EntityInterface::urlInfo() is deprecated in Drupal 8.0.0 and will be removed in Drupal 9.0.0. EntityInterface::toUrl() instead. See https://www.drupal.org/node/2614344', E_USER_DEPRECATED);
-    return $this->toUrl($rel, $options);
   }
 
   /**
@@ -264,14 +234,6 @@ abstract class EntityBase implements EntityInterface {
     return $this->getEntityType()->getLinkTemplates();
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function link($text = NULL, $rel = 'canonical', array $options = []) {
-    @trigger_error("EntityInterface::link() is deprecated in Drupal 8.0.0 and will be removed in Drupal 9.0.0. Use EntityInterface::toLink()->toString() instead. Note, the default relationship for configuration entities changes from 'edit-form' to 'canonical'. See https://www.drupal.org/node/2614344", E_USER_DEPRECATED);
-    return $this->toLink($text, $rel, $options)->toString();
-  }
-
   /**
    * {@inheritdoc}
    */
@@ -285,23 +247,6 @@ abstract class EntityBase implements EntityInterface {
     return new Link($text, $url);
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function url($rel = 'canonical', $options = []) {
-    @trigger_error('EntityInterface::url() is deprecated in Drupal 8.0.0 and will be removed in Drupal 9.0.0. EntityInterface::toUrl() instead. Note, a \Drupal\Core\Url object is returned. See https://www.drupal.org/node/2614344', E_USER_DEPRECATED);
-    // While self::toUrl() will throw an exception if the entity has no id,
-    // the expected result for a URL is always a string.
-    if ($this->id() === NULL || !$this->hasLinkTemplate($rel)) {
-      return '';
-    }
-
-    $uri = $this->toUrl($rel);
-    $options += $uri->getOptions();
-    $uri->setOptions($options);
-    return $uri->toString();
-  }
-
   /**
    * Gets an array of placeholders for this entity.
    *
@@ -492,12 +437,24 @@ abstract class EntityBase implements EntityInterface {
     return $this->cacheContexts;
   }
 
+  /**
+   * The list cache tags to invalidate for this entity.
+   *
+   * @return string[]
+   *   Set of list cache tags.
+   */
+  protected function getListCacheTagsToInvalidate() {
+    $tags = $this->getEntityType()->getListCacheTags();
+    if ($this->getEntityType()->hasKey('bundle')) {
+      $tags[] = $this->getEntityTypeId() . '_list:' . $this->bundle();
+    }
+    return $tags;
+  }
+
   /**
    * {@inheritdoc}
    */
   public function getCacheTagsToInvalidate() {
-    // @todo Add bundle-specific listing cache tag?
-    //   https://www.drupal.org/node/2145751
     if ($this->isNew()) {
       return [];
     }
@@ -562,7 +519,7 @@ abstract class EntityBase implements EntityInterface {
     // updated entity may start to appear in a listing because it now meets that
     // listing's filtering requirements. A newly created entity may start to
     // appear in listings because it did not exist before.)
-    $tags = $this->getEntityType()->getListCacheTags();
+    $tags = $this->getListCacheTagsToInvalidate();
     if ($this->hasLinkTemplate('canonical')) {
       // Creating or updating an entity may change a cached 403 or 404 response.
       $tags = Cache::mergeTags($tags, ['4xx-response']);
@@ -591,6 +548,7 @@ abstract class EntityBase implements EntityInterface {
       // cache tag, but subsequent list pages would not be invalidated, hence we
       // must invalidate its list cache tags as well.)
       $tags = Cache::mergeTags($tags, $entity->getCacheTagsToInvalidate());
+      $tags = Cache::mergeTags($tags, $entity->getListCacheTagsToInvalidate());
     }
     Cache::invalidateTags($tags);
   }
