@@ -2,7 +2,6 @@
 
 namespace Drupal\Core\Entity;
 
-use Drupal\Core\DependencyInjection\DeprecatedServicePropertyTrait;
 use Drupal\Core\Form\FormBuilderInterface;
 use Drupal\Core\Form\FormState;
 
@@ -10,12 +9,6 @@ use Drupal\Core\Form\FormState;
  * Builds entity forms.
  */
 class EntityFormBuilder implements EntityFormBuilderInterface {
-  use DeprecatedServicePropertyTrait;
-
-  /**
-   * {@inheritdoc}
-   */
-  protected $deprecatedProperties = ['entityManager' => 'entity.manager'];
 
   /**
    * The entity type manager service.
@@ -40,13 +33,7 @@ class EntityFormBuilder implements EntityFormBuilderInterface {
    *   The form builder.
    */
   public function __construct(EntityTypeManagerInterface $entity_type_manager, FormBuilderInterface $form_builder) {
-    if ($entity_type_manager instanceof EntityManagerInterface) {
-      @trigger_error('Passing the entity.manager service to EntityFormBuilder::__construct() is deprecated in Drupal 8.7.0 and will be removed before Drupal 9.0.0. Pass the new dependencies instead. See https://www.drupal.org/node/2549139.', E_USER_DEPRECATED);
-      $this->entityTypeManager = \Drupal::entityTypeManager();
-    }
-    else {
-      $this->entityTypeManager = $entity_type_manager;
-    }
+    $this->entityTypeManager = $entity_type_manager;
     $this->formBuilder = $form_builder;
   }
 
