@@ -7,7 +7,9 @@ use Drupal\Core\Config\ConfigImporter;
 use Drupal\Core\Config\ConfigImporterEvent;
 use Drupal\Core\Config\ConfigImportValidateEventSubscriberBase;
 use Drupal\Core\Config\ConfigNameException;
+use Drupal\Core\Extension\ModuleExtensionList;
 use Drupal\Core\Extension\ThemeHandlerInterface;
+use Drupal\Core\Installer\InstallerKernel;
 
 /**
  * Config import subscriber for config import events.
@@ -22,11 +24,11 @@ class ConfigImportSubscriber extends ConfigImportValidateEventSubscriberBase {
   protected $themeData;
 
   /**
-   * Module data.
+   * Module extension list.
    *
-   * @var \Drupal\Core\Extension\Extension[]
+   * @var \Drupal\Core\Extension\ModuleExtensionList
    */
-  protected $moduleData;
+  protected $moduleExtensionList;
 
   /**
    * The theme handler.
@@ -40,9 +42,12 @@ class ConfigImportSubscriber extends ConfigImportValidateEventSubscriberBase {
    *
    * @param \Drupal\Core\Extension\ThemeHandlerInterface $theme_handler
    *   The theme handler.
+   * @param \Drupal\Core\Extension\ModuleExtensionList $extension_list_module
+   *   The module extension list.
    */
-  public function __construct(ThemeHandlerInterface $theme_handler) {
+  public function __construct(ThemeHandlerInterface $theme_handler, ModuleExtensionList $extension_list_module) {
     $this->themeHandler = $theme_handler;
+    $this->moduleExtensionList = $extension_list_module;
   }
 
   /**
@@ -91,7 +96,7 @@ class ConfigImportSubscriber extends ConfigImportValidateEventSubscriberBase {
 
     // Ensure the profile is not changing.
     if ($install_profile !== $core_extension['profile']) {
-      if (drupal_installation_attempted()) {
+      if (InstallerKernel::installationAttempted()) {
         $config_importer->logError($this->t('The selected installation profile %install_profile does not match the profile stored in configuration %config_profile.', [
           '%install_profile' => $install_profile,
           '%config_profile' => $core_extension['profile'],
@@ -108,7 +113,7 @@ class ConfigImportSubscriber extends ConfigImportValidateEventSubscriberBase {
     }
 
     // Get a list of modules with dependency weights as values.
-    $module_data = $this->getModuleData();
+    $module_data = $this->moduleExtensionList->getList();
     $nonexistent_modules = array_keys(array_diff_key($core_extension['module'], $module_data));
     foreach ($nonexistent_modules as $module) {
       $config_importer->logError($this->t('Unable to install the %module module since it does not exist.', ['%module' => $module]));
@@ -214,7 +219,7 @@ class ConfigImportSubscriber extends ConfigImportValidateEventSubscriberBase {
     ];
 
     $theme_data = $this->getThemeData();
-    $module_data = $this->getModuleData();
+    $module_data = $this->moduleExtensionList->getList();
 
     // Validate the dependencies of all the configuration. We have to validate
     // the entire tree because existing configuration might depend on
@@ -271,6 +276,7 @@ class ConfigImportSubscriber extends ConfigImportValidateEventSubscriberBase {
                   ['%name' => $name, '%module' => implode(', ', $this->getNames($diffs, $module_data))]
                 );
                 break;
+
               case 'theme':
                 $message = $this->formatPlural(
                   count($diffs),
@@ -279,6 +285,7 @@ class ConfigImportSubscriber extends ConfigImportValidateEventSubscriberBase {
                   ['%name' => $name, '%theme' => implode(', ', $this->getNames($diffs, $theme_data))]
                 );
                 break;
+
               case 'config':
                 $message = $this->formatPlural(
                   count($diffs),
@@ -310,18 +317,6 @@ class ConfigImportSubscriber extends ConfigImportValidateEventSubscriberBase {
     return $this->themeData;
   }
 
-  /**
-   * Gets module data.
-   *
-   * @return \Drupal\Core\Extension\Extension[]
-   */
-  protected function getModuleData() {
-    if (!isset($this->moduleData)) {
-      $this->moduleData = system_rebuild_module_data();
-    }
-    return $this->moduleData;
-  }
-
   /**
    * Gets human readable extension names.
    *
