@@ -33,7 +33,7 @@ class InfoParserDynamic implements InfoParserInterface {
     if ($app_root === NULL) {
       // @todo https://www.drupal.org/project/drupal/issues/3087975 Require
       //   $app_root argument.
-      $app_root = \Drupal::hasService('app.root') ? (string) \Drupal::service('app.root') : DRUPAL_ROOT;
+      $app_root = \Drupal::hasService('kernel') ? \Drupal::root() : DRUPAL_ROOT;
     }
     $this->root = $app_root;
   }
@@ -56,7 +56,7 @@ class InfoParserDynamic implements InfoParserInterface {
       if (!empty($missing_keys)) {
         throw new InfoParserException('Missing required keys (' . implode(', ', $missing_keys) . ') in ' . $filename);
       }
-      if (!isset($parsed_info['core']) && !isset($parsed_info['core_version_requirement'])) {
+      if (!isset($parsed_info['core_version_requirement'])) {
         if (strpos($filename, 'core/') === 0 || strpos($filename, $this->root . '/core/') === 0) {
           // Core extensions do not need to specify core compatibility: they are
           // by definition compatible so a sensible default is used. Core
@@ -68,14 +68,11 @@ class InfoParserDynamic implements InfoParserInterface {
           // easier for contrib to use test modules.
           $parsed_info['core_version_requirement'] = \Drupal::VERSION;
         }
-        else {
+        elseif (!isset($parsed_info['core'])) {
           // Non-core extensions must specify core compatibility.
-          throw new InfoParserException("The 'core' or the 'core_version_requirement' key must be present in " . $filename);
+          throw new InfoParserException("The 'core_version_requirement' key must be present in " . $filename);
         }
       }
-      if (isset($parsed_info['core']) && !preg_match("/^\d\.x$/", $parsed_info['core'])) {
-        throw new InfoParserException("Invalid 'core' value \"{$parsed_info['core']}\" in " . $filename);
-      }
       if (isset($parsed_info['core_version_requirement'])) {
         try {
           $supports_pre_core_version_requirement_version = static::isConstraintSatisfiedByPreviousVersion($parsed_info['core_version_requirement'], static::FIRST_CORE_VERSION_REQUIREMENT_SUPPORTED_VERSION);
@@ -99,6 +96,9 @@ class InfoParserDynamic implements InfoParserInterface {
           throw new InfoParserException("The 'core_version_requirement' can not be used to specify compatibility for a specific version before " . static::FIRST_CORE_VERSION_REQUIREMENT_SUPPORTED_VERSION . " in $filename");
         }
       }
+      if (isset($parsed_info['core']) && $parsed_info['core'] !== '8.x') {
+        throw new InfoParserException("'core: {$parsed_info['core']}' is not supported. Use 'core_version_requirement' to specify core compatibility. Only 'core: 8.x' is supported to provide backwards compatibility for Drupal 8 when needed in $filename");
+      }
 
       // Determine if the extension is compatible with the current version of
       // Drupal core.
@@ -107,24 +107,6 @@ class InfoParserDynamic implements InfoParserInterface {
       if (isset($parsed_info['version']) && $parsed_info['version'] === 'VERSION') {
         $parsed_info['version'] = \Drupal::VERSION;
       }
-      // Special backwards compatible handling profiles and their 'dependencies'
-      // key.
-      if ($parsed_info['type'] === 'profile' && isset($parsed_info['dependencies']) && !array_key_exists('install', $parsed_info)) {
-        // Only trigger the deprecation message if we are actually using the
-        // profile with the missing 'install' key. This avoids triggering the
-        // deprecation when scanning all the available install profiles.
-        global $install_state;
-        if (isset($install_state['parameters']['profile'])) {
-          $pattern = '@' . preg_quote(DIRECTORY_SEPARATOR . $install_state['parameters']['profile'] . '.info.yml') . '$@';
-          if (preg_match($pattern, $filename)) {
-            @trigger_error("The install profile $filename only implements a 'dependencies' key. As of Drupal 8.6.0 profile's support a new 'install' key for modules that should be installed but not depended on. See https://www.drupal.org/node/2952947.", E_USER_DEPRECATED);
-          }
-        }
-        // Move dependencies to install so that if a profile has both
-        // dependencies and install then dependencies are real.
-        $parsed_info['install'] = $parsed_info['dependencies'];
-        $parsed_info['dependencies'] = [];
-      }
     }
     return $parsed_info;
   }
