@@ -1,10 +1,5 @@
 <?php
 
-/**
- * @file
- * Contains \Drupal\Core\Field\Plugin\Field\FieldType\PasswordItem.
- */
-
 namespace Drupal\Core\Field\Plugin\Field\FieldType;
 
 use Drupal\Core\Entity\EntityMalformedException;
@@ -33,6 +28,8 @@ class PasswordItem extends StringItem {
       ->setSetting('case_sensitive', TRUE);
     $properties['existing'] = DataDefinition::create('string')
       ->setLabel(new TranslatableMarkup('Existing password'));
+    $properties['pre_hashed'] = DataDefinition::create('boolean')
+      ->setLabel(new TranslatableMarkup('Determines if a password needs hashing'));
 
     return $properties;
   }
@@ -45,8 +42,11 @@ class PasswordItem extends StringItem {
 
     $entity = $this->getEntity();
 
-    // Update the user password if it has changed.
-    if ($entity->isNew() || (strlen(trim($this->value)) > 0 && $this->value != $entity->original->{$this->getFieldDefinition()->getName()}->value)) {
+    if ($this->pre_hashed) {
+      // Reset the pre_hashed value since it has now been used.
+      $this->pre_hashed = FALSE;
+    }
+    elseif ($entity->isNew() || (strlen(trim($this->value)) > 0 && $this->value != $entity->original->{$this->getFieldDefinition()->getName()}->value)) {
       // Allow alternate password hashing schemes.
       $this->value = \Drupal::service('password')->hash(trim($this->value));
       // Abort if the hashing failed and returned FALSE.
