@@ -2,11 +2,31 @@
 
 namespace Drupal\Core\FileTransfer;
 
+use Drupal\Core\DependencyInjection\DependencySerializationTrait;
+use Drupal\Core\File\FileSystemInterface;
+
 /**
  * Defines the local connection class for copying files as the httpd user.
  */
 class Local extends FileTransfer implements ChmodInterface {
 
+  use DependencySerializationTrait;
+
+  /**
+   * The file system service.
+   *
+   * @var \Drupal\Core\File\FileSystemInterface
+   */
+  protected $fileSystem;
+
+  /**
+   * {@inheritdoc}
+   */
+  public function __construct($jail, FileSystemInterface $file_system) {
+    parent::__construct($jail);
+    $this->fileSystem = $file_system;
+  }
+
   /**
    * {@inheritdoc}
    */
@@ -18,7 +38,7 @@ class Local extends FileTransfer implements ChmodInterface {
    * {@inheritdoc}
    */
   public static function factory($jail, $settings) {
-    return new Local($jail);
+    return new Local($jail, \Drupal::service('file_system'));
   }
 
   /**
@@ -56,7 +76,7 @@ class Local extends FileTransfer implements ChmodInterface {
         }
       }
       elseif ($file->isFile()) {
-        if (@!drupal_unlink($filename)) {
+        if (@!$this->fileSystem->unlink($filename)) {
           throw new FileTransferException('Cannot remove file %file.', NULL, ['%file' => $filename]);
         }
       }
@@ -70,7 +90,7 @@ class Local extends FileTransfer implements ChmodInterface {
    * {@inheritdoc}
    */
   protected function removeFileJailed($file) {
-    if (@!drupal_unlink($file)) {
+    if (@!$this->fileSystem->unlink($file)) {
       throw new FileTransferException('Cannot remove file %file.', NULL, ['%file' => $file]);
     }
   }
