@@ -45,6 +45,6 @@ interface OutboundPathProcessorInterface {
    * @return string
    *   The processed path.
    */
-  public function processOutbound($path, &$options = array(), Request $request = NULL, BubbleableMetadata $bubbleable_metadata = NULL);
+  public function processOutbound($path, &$options = [], Request $request = NULL, BubbleableMetadata $bubbleable_metadata = NULL);
 
 }
