@@ -2,9 +2,9 @@
 
 namespace Drupal\Core\Plugin;
 
-use Drupal\Component\Plugin\ConfigurablePluginInterface;
 use Drupal\Component\Plugin\ContextAwarePluginBase as ComponentContextAwarePluginBase;
 use Drupal\Component\Plugin\Exception\ContextException;
+use Drupal\Component\Plugin\PluginHelper;
 use Drupal\Core\Cache\Cache;
 use Drupal\Core\Cache\CacheableDependencyInterface;
 use Drupal\Core\DependencyInjection\DependencySerializationTrait;
@@ -78,7 +78,7 @@ abstract class ContextAwarePluginBase extends ComponentContextAwarePluginBase im
    * {@inheritdoc}
    */
   public function getContextMapping() {
-    $configuration = $this instanceof ConfigurablePluginInterface ? $this->getConfiguration() : $this->configuration;
+    $configuration = PluginHelper::isConfigurable($this) ? $this->getConfiguration() : $this->configuration;
     return isset($configuration['context_mapping']) ? $configuration['context_mapping'] : [];
   }
 
@@ -86,7 +86,7 @@ abstract class ContextAwarePluginBase extends ComponentContextAwarePluginBase im
    * {@inheritdoc}
    */
   public function setContextMapping(array $context_mapping) {
-    if ($this instanceof ConfigurablePluginInterface) {
+    if (PluginHelper::isConfigurable($this)) {
       $configuration = $this->getConfiguration();
       $configuration['context_mapping'] = array_filter($context_mapping);
       $this->setConfiguration($configuration);
