@@ -2,8 +2,8 @@
 
 namespace Drupal\Core\StreamWrapper;
 
-use Drupal\Core\Routing\UrlGeneratorTrait;
 use Drupal\Core\Site\Settings;
+use Drupal\Core\Url;
 
 /**
  * Drupal private (private://) stream wrapper class.
@@ -13,8 +13,6 @@ use Drupal\Core\Site\Settings;
  */
 class PrivateStream extends LocalStream {
 
-  use UrlGeneratorTrait;
-
   /**
    * {@inheritdoc}
    */
@@ -48,7 +46,7 @@ class PrivateStream extends LocalStream {
    */
   public function getExternalUrl() {
     $path = str_replace('\\', '/', $this->getTarget());
-    return $this->url('system.private_file_download', ['filepath' => $path], ['absolute' => TRUE, 'path_processing' => FALSE]);
+    return Url::fromRoute('system.private_file_download', ['filepath' => $path], ['absolute' => TRUE, 'path_processing' => FALSE])->toString();
   }
 
   /**
