@@ -2,8 +2,7 @@
 
 namespace Drupal\Core\Template\Loader;
 
-use Twig\Loader\ExistsLoaderInterface;
-use Twig\Loader\SourceContextLoaderInterface;
+use Twig\Loader\LoaderInterface;
 use Twig\Source;
 
 /**
@@ -18,13 +17,13 @@ use Twig\Source;
  * This class override ensures that the string loader behaves as expected in
  * the loader chain. If Twig's string loader is used as is, any string (even a
  * reference to a file-based Twig template) is treated as a valid template and
- * is rendered instead of a \Twig_Error_Loader exception being thrown.
+ * is rendered instead of a \Twig\Error\LoaderError exception being thrown.
  *
  * @see \Drupal\Core\Template\TwigEnvironment::renderInline()
  * @see \Drupal\Core\Render\Element\InlineTemplate
  * @see twig_render_template()
  */
-class StringLoader implements \Twig_LoaderInterface, ExistsLoaderInterface, SourceContextLoaderInterface {
+class StringLoader implements LoaderInterface {
 
   /**
    * {@inheritdoc}
@@ -38,13 +37,6 @@ class StringLoader implements \Twig_LoaderInterface, ExistsLoaderInterface, Sour
     }
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function getSource($name) {
-    return $name;
-  }
-
   /**
    * {@inheritdoc}
    */
