@@ -3,11 +3,9 @@
 namespace Drupal\Core\TypedData\Validation;
 
 use Drupal\Core\TypedData\TypedDataInterface;
-use Symfony\Component\Validator\Exception\BadMethodCallException;
 use Symfony\Component\Validator\Mapping\CascadingStrategy;
 use Symfony\Component\Validator\Mapping\MetadataInterface;
 use Symfony\Component\Validator\Mapping\TraversalStrategy;
-use Symfony\Component\Validator\ValidationVisitorInterface;
 
 /**
  * Validator metadata for typed data objects.
@@ -33,13 +31,6 @@ class TypedDataMetadata implements MetadataInterface {
     $this->typedData = $typed_data;
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function accept(ValidationVisitorInterface $visitor, $typed_data, $group, $propertyPath) {
-    throw new BadMethodCallException('Not supported.');
-  }
-
   /**
    * {@inheritdoc}
    */
