@@ -6,7 +6,7 @@ use Drupal\Tests\SchemaCheckTestTrait;
 use Drupal\Tests\migrate_drupal\Kernel\d7\MigrateDrupal7TestBase;
 
 /**
- * Upgrade variables to action.settings.yml.
+ * Upgrade variables to null.
  *
  * @group migrate_drupal_7
  */
@@ -17,23 +17,22 @@ class MigrateActionConfigsTest extends MigrateDrupal7TestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['action'];
+  protected static $modules = ['action'];
 
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->executeMigration('action_settings');
   }
 
   /**
-   * Tests migration of action variables to action.settings.yml.
+   * Tests migration of action variables to null.
    */
   public function testActionSettings() {
     $config = $this->config('action.settings');
-    $this->assertSame(28, $config->get('recursion_limit'));
-    $this->assertConfigSchema(\Drupal::service('config.typed'), 'action.settings', $config->get());
+    $this->assertTrue($config->isNew());
   }
 
 }
