@@ -2,7 +2,6 @@
 
 namespace Drupal\Tests\aggregator\Functional;
 
-use Drupal\Component\Render\FormattableMarkup;
 use Drupal\aggregator\FeedStorageInterface;
 use Drupal\Core\Url;
 use Drupal\aggregator\Entity\Feed;
@@ -23,7 +22,7 @@ class FeedParserTest extends AggregatorTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     // Do not delete old aggregator items during these tests, since our sample
     // feeds have hardcoded dates in them (which may be expired when this test
@@ -38,7 +37,7 @@ class FeedParserTest extends AggregatorTestBase {
     $feed = $this->createFeed($this->getRSS091Sample());
     $feed->refreshItems();
     $this->drupalGet('aggregator/sources/' . $feed->id());
-    $this->assertResponse(200, new FormattableMarkup('Feed %name exists.', ['%name' => $feed->label()]));
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText('First example feed item title');
     $this->assertLinkByHref('http://example.com/example-turns-one');
     $this->assertText('First example feed item description.');
@@ -61,7 +60,7 @@ class FeedParserTest extends AggregatorTestBase {
     $feed = $this->createFeed($this->getAtomSample());
     $feed->refreshItems();
     $this->drupalGet('aggregator/sources/' . $feed->id());
-    $this->assertResponse(200, new FormattableMarkup('Feed %name exists.', ['%name' => $feed->label()]));
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText('Atom-Powered Robots Run Amok');
     $this->assertLinkByHref('http://example.org/2003/12/13/atom03');
     $this->assertText('Some text.');
@@ -85,7 +84,7 @@ class FeedParserTest extends AggregatorTestBase {
     $feed = $this->createFeed($this->getHtmlEntitiesSample());
     $feed->refreshItems();
     $this->drupalGet('aggregator/sources/' . $feed->id());
-    $this->assertResponse(200, new FormattableMarkup('Feed %name exists.', ['%name' => $feed->label()]));
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw("Quote&quot; Amp&amp;");
   }
 
