@@ -14,7 +14,7 @@ class ItemHalJsonAnonTest extends ItemHalJsonTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['hal'];
+  protected static $modules = ['hal'];
 
   /**
    * {@inheritdoc}
