@@ -48,7 +48,7 @@ class ThemeLocalTask extends DeriverBase implements ContainerDeriverInterface {
       if ($this->themeHandler->hasUi($theme_name)) {
         $this->derivatives[$theme_name] = $base_plugin_definition;
         $this->derivatives[$theme_name]['title'] = $theme->info['name'];
-        $this->derivatives[$theme_name]['route_parameters'] = array('theme' => $theme_name);
+        $this->derivatives[$theme_name]['route_parameters'] = ['theme' => $theme_name];
       }
       // Default task!
       if ($default_theme == $theme_name) {
