@@ -14,7 +14,7 @@ class BlockContentPageViewTest extends BlockContentTestBase {
    *
    * @var array
    */
-  public static $modules = ['block_content_test'];
+  protected static $modules = ['block_content_test'];
 
   /**
    * {@inheritdoc}
@@ -31,8 +31,8 @@ class BlockContentPageViewTest extends BlockContentTestBase {
     // Attempt to view the block.
     $this->drupalGet('block-content/' . $block->id());
 
-    // Assert response was '200' and not '403 Access denied'.
-    $this->assertResponse('200', 'User was able the view the block');
+    // Ensure user was able to view the block.
+    $this->assertSession()->statusCodeEquals(200);
     $this->drupalGet('<front>');
     $this->assertRaw(t('This block is broken or missing. You may be missing content or you might need to enable the original module.'));
   }
