@@ -208,20 +208,6 @@ interface CommentInterface extends ContentEntityInterface, EntityChangedInterfac
    */
   public function setCreatedTime($created);
 
-  /**
-   * Returns the comment's status.
-   *
-   * @return int|string|bool
-   *   Either TRUE, '1', or CommentInterface::PUBLISHED(1) if the comment is
-   *   published, or FALSE, '0', or CommentInterface::NOT_PUBLISHED(0) if the
-   *   comment is not published.
-   *
-   * @deprecated in drupal:8.3.0 and is removed from drupal:9.0.0. Use
-   *   \Drupal\Core\Entity\EntityPublishedInterface::isPublished() instead.
-   * @see https://www.drupal.org/node/2830201
-   */
-  public function getStatus();
-
   /**
    * Returns the alphadecimal representation of the comment's place in a thread.
    *
