@@ -2,6 +2,7 @@
 
 namespace Drupal\Tests\comment\Functional;
 
+use Drupal\Component\Render\FormattableMarkup;
 use Drupal\comment\CommentManagerInterface;
 
 /**
@@ -11,6 +12,11 @@ use Drupal\comment\CommentManagerInterface;
  */
 class CommentThreadingTest extends CommentTestBase {
 
+  /**
+   * {@inheritdoc}
+   */
+  protected $defaultTheme = 'classy';
+
   /**
    * Tests the comment threading.
    */
@@ -137,7 +143,7 @@ class CommentThreadingTest extends CommentTestBase {
     //  </article>
     $pattern = "//article[@id='comment-$cid']//p[contains(@class, 'parent')]//a[contains(@href, 'comment-$pid')]";
 
-    $this->assertFieldByXpath($pattern, NULL, format_string(
+    $this->assertFieldByXpath($pattern, NULL, new FormattableMarkup(
       'Comment %cid has a link to parent %pid.',
       [
         '%cid' => $cid,
@@ -160,7 +166,7 @@ class CommentThreadingTest extends CommentTestBase {
     //  </article>
 
     $pattern = "//article[@id='comment-$cid']//p[contains(@class, 'parent')]";
-    $this->assertNoFieldByXpath($pattern, NULL, format_string(
+    $this->assertNoFieldByXpath($pattern, NULL, new FormattableMarkup(
       'Comment %cid does not have a link to a parent.',
       [
         '%cid' => $cid,
