@@ -43,7 +43,7 @@ class CommentTypeTest extends CommentTestBase {
   /**
    * Sets the test up.
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalPlaceBlock('page_title_block');
@@ -59,13 +59,14 @@ class CommentTypeTest extends CommentTestBase {
     $type = $this->createCommentType('other');
 
     $comment_type = CommentType::load('other');
-    $this->assertInstanceOf(CommentType::class, $comment_type, 'The new comment type has been created.');
+    $this->assertInstanceOf(CommentType::class, $comment_type);
 
     // Log in a test user.
     $this->drupalLogin($this->adminUser);
 
+    // Ensure that the new comment type admin page can be accessed.
     $this->drupalGet('admin/structure/comment/manage/' . $type->id());
-    $this->assertResponse(200, 'The new comment type can be accessed at the edit form.');
+    $this->assertSession()->statusCodeEquals(200);
 
     // Create a comment type via the user interface.
     $edit = [
@@ -76,7 +77,7 @@ class CommentTypeTest extends CommentTestBase {
     ];
     $this->drupalPostForm('admin/structure/comment/types/add', $edit, t('Save'));
     $comment_type = CommentType::load('foo');
-    $this->assertInstanceOf(CommentType::class, $comment_type, 'The new comment type has been created.');
+    $this->assertInstanceOf(CommentType::class, $comment_type);
 
     // Check that the comment type was created in site default language.
     $default_langcode = \Drupal::languageManager()->getDefaultLanguage()->getId();
