@@ -10,6 +10,11 @@ namespace Drupal\Tests\comment\Functional\Views;
  */
 class RowRssTest extends CommentTestBase {
 
+  /**
+   * {@inheritdoc}
+   */
+  protected $defaultTheme = 'stark';
+
   /**
    * Views used by this test.
    *
@@ -26,7 +31,7 @@ class RowRssTest extends CommentTestBase {
     // Because the response is XML we can't use the page which depends on an
     // HTML tag being present.
     $result = $this->getSession()->getDriver()->find('//item');
-    $this->assertEqual(count($result), 1, 'Just one comment was found in the rss output.');
+    $this->assertCount(1, $result, 'Just one comment was found in the rss output.');
 
     $this->assertEqual($result[0]->find('xpath', '//pubDate')->getHtml(), gmdate('r', $this->comment->getCreatedTime()), 'The right pubDate appears in the rss output.');
   }
