@@ -25,7 +25,7 @@ class ViewsModerationStateFilterTest extends ViewsKernelTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = [
+  protected static $modules = [
     'content_moderation_test_views',
     'node',
     'content_moderation',
@@ -39,7 +39,7 @@ class ViewsModerationStateFilterTest extends ViewsKernelTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp($import_test_views = TRUE) {
+  protected function setUp($import_test_views = TRUE): void {
     parent::setUp(FALSE);
 
     $this->installEntitySchema('user');
@@ -150,7 +150,7 @@ class ViewsModerationStateFilterTest extends ViewsKernelTestBase {
       'moderation_state' => 'editorial-draft',
     ], 'test_content_moderation_state_filter_revision_table');
     // Creating a new forward revision of node three, creates a second published
-    // revision of of the original language, hence there are two published
+    // revision of the original language, hence there are two published
     // revisions of node three.
     $this->assertNodesWithFilters([$node, $third_node, $third_node], [
       'moderation_state' => 'editorial-published',
