@@ -52,7 +52,7 @@ class ContentTranslationContextualLinksTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['content_translation', 'contextual', 'node'];
+  protected static $modules = ['content_translation', 'contextual', 'node'];
 
   /**
    * The profile to install as a basis for testing.
@@ -61,7 +61,7 @@ class ContentTranslationContextualLinksTest extends BrowserTestBase {
    */
   protected $profile = 'testing';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     // Set up an additional language.
     $this->langcodes = [\Drupal::languageManager()->getDefaultLanguage()->getId(), 'es'];
