@@ -16,7 +16,7 @@ class ContentTranslationUISkipTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['content_translation_test', 'user', 'node'];
+  protected static $modules = ['content_translation_test', 'user', 'node'];
 
   /**
    * {@inheritdoc}
