@@ -24,7 +24,7 @@ class DbLogTest extends KernelTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->installSchema('dblog', ['watchdog']);
