@@ -59,7 +59,11 @@ class EntityReferenceIntegrationTest extends BrowserTestBase {
     parent::setUp();
 
     // Create a test user.
-    $web_user = $this->drupalCreateUser(['administer entity_test content', 'administer entity_test fields', 'view test entity']);
+    $web_user = $this->drupalCreateUser([
+      'administer entity_test content',
+      'administer entity_test fields',
+      'view test entity',
+    ]);
     $this->drupalLogin($web_user);
   }
 
