@@ -69,7 +69,10 @@ class FormTest extends FieldTestBase {
   protected function setUp(): void {
     parent::setUp();
 
-    $web_user = $this->drupalCreateUser(['view test entity', 'administer entity_test content']);
+    $web_user = $this->drupalCreateUser([
+      'view test entity',
+      'administer entity_test content',
+    ]);
     $this->drupalLogin($web_user);
 
     $this->fieldStorageSingle = [
