@@ -15,7 +15,7 @@ class FieldOptionTranslationTest extends MigrateSqlSourceTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['field', 'migrate_drupal'];
+  protected static $modules = ['field', 'migrate_drupal'];
 
   /**
    * {@inheritdoc}
@@ -110,6 +110,14 @@ class FieldOptionTranslationTest extends MigrateSqlSourceTestBase {
         'objectindex' => 0,
         'format' => 0,
       ],
+      [
+        'lid' => 22,
+        'objectid' => 'field_test_integer_selectlist',
+        'type' => 'field',
+        'property' => 'option_0',
+        'objectindex' => 0,
+        'format' => 0,
+      ],
     ];
     $test[0]['source_data']['locales_target'] = [
       [
