@@ -9,20 +9,6 @@ use Drupal\Core\Config\Entity\ConfigEntityInterface;
  */
 interface ImageStyleInterface extends ConfigEntityInterface {
 
-  /**
-   * Returns the replacement ID.
-   *
-   * @return string|null
-   *   The replacement image style ID or NULL if no replacement has been
-   *   selected.
-   *
-   * @deprecated in drupal:8.0.0 and is removed from drupal:9.0.0. Use
-   *   \Drupal\image\ImageStyleStorageInterface::getReplacementId() instead.
-   *
-   * @see \Drupal\image\ImageStyleStorageInterface::getReplacementId()
-   */
-  public function getReplacementID();
-
   /**
    * Returns the image style.
    *
