@@ -25,7 +25,7 @@ class FileMoveTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['image'];
+  protected static $modules = ['image'];
 
   /**
    * {@inheritdoc}
@@ -47,7 +47,7 @@ class FileMoveTest extends BrowserTestBase {
     $style->createDerivative($original_uri, $derivative_uri);
 
     // Check if derivative image exists.
-    $this->assertTrue(file_exists($derivative_uri), 'Make sure derivative image is generated successfully.');
+    $this->assertFileExists($derivative_uri);
 
     // Clone the object so we don't have to worry about the function changing
     // our reference copy.
@@ -55,10 +55,10 @@ class FileMoveTest extends BrowserTestBase {
     $result = file_move(clone $file, $desired_filepath, FileSystemInterface::EXISTS_ERROR);
 
     // Check if image has been moved.
-    $this->assertTrue(file_exists($result->getFileUri()), 'Make sure image is moved successfully.');
+    $this->assertFileExists($result->getFileUri());
 
     // Check if derivative image has been flushed.
-    $this->assertFalse(file_exists($derivative_uri), 'Make sure derivative image has been flushed.');
+    $this->assertFileNotExists($derivative_uri);
   }
 
 }
