@@ -242,9 +242,9 @@ class FieldResolver {
    * elide the "entity" keyword from them (this word is used by the entity query
    * system to traverse entity references).
    *
-   * This method takes this external field expression and and attempts to
-   * resolve any aliases and/or abbreviations into a field expression that will
-   * be compatible with the entity query system.
+   * This method takes this external field expression and attempts to resolve
+   * any aliases and/or abbreviations into a field expression that will be
+   * compatible with the entity query system.
    *
    * @link http://jsonapi.org/recommendations/#urls-reference-document
    *
@@ -262,20 +262,7 @@ class FieldResolver {
    *
    * @throws \Drupal\Core\Http\Exception\CacheableBadRequestHttpException
    */
-  public function resolveInternalEntityQueryPath($resource_type, $external_field_name) {
-    $function_args = func_get_args();
-    // @todo Remove this conditional block in drupal:9.0.0 and add a type hint
-    // to the first argument of this method.
-    // @see https://www.drupal.org/project/drupal/issues/3078045
-    if (count($function_args) === 3) {
-      @trigger_error('Passing the entity type ID and bundle to ' . __METHOD__ . ' is deprecated in drupal:8.8.0 and will throw a fatal error in drupal:9.0.0. Pass a JSON:API resource type instead. See https://www.drupal.org/node/3078036', E_USER_DEPRECATED);
-      list($entity_type_id, $bundle, $external_field_name) = $function_args;
-      $resource_type = $this->resourceTypeRepository->get($entity_type_id, $bundle);
-    }
-    elseif (!$resource_type instanceof ResourceType) {
-      throw new \InvalidArgumentException("The first argument to " . __METHOD__ . " should be an instance of \Drupal\jsonapi\ResourceType\ResourceType, " . gettype($resource_type) . " given.");
-    }
-
+  public function resolveInternalEntityQueryPath(ResourceType $resource_type, $external_field_name) {
     $cacheability = (new CacheableMetadata())->addCacheContexts(['url.query_args:filter', 'url.query_args:sort']);
     if (empty($external_field_name)) {
       throw new CacheableBadRequestHttpException($cacheability, 'No field name was provided for the filter.');
