@@ -19,7 +19,7 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = [
+  protected static $modules = [
     'basic_auth',
   ];
 
@@ -48,7 +48,7 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
       'query' => $default_sort,
     ]));
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertEquals(OffsetPage::SIZE_MAX, count($collection_output['data']));
+    $this->assertCount(OffsetPage::SIZE_MAX, $collection_output['data']);
     $this->assertSession()
       ->responseHeaderEquals('Content-Type', 'application/vnd.api+json');
     // 2. Load all articles (Offset 3).
@@ -56,14 +56,14 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
       'query' => ['page' => ['offset' => 3]] + $default_sort,
     ]));
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertEquals(OffsetPage::SIZE_MAX, count($collection_output['data']));
-    $this->assertContains('page%5Boffset%5D=53', $collection_output['links']['next']['href']);
+    $this->assertCount(OffsetPage::SIZE_MAX, $collection_output['data']);
+    $this->assertStringContainsString('page%5Boffset%5D=53', $collection_output['links']['next']['href']);
     // 3. Load all articles (1st page, 2 items)
     $collection_output = Json::decode($this->drupalGet('/jsonapi/node/article', [
       'query' => ['page' => ['limit' => 2]] + $default_sort,
     ]));
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertEquals(2, count($collection_output['data']));
+    $this->assertCount(2, $collection_output['data']);
     // 4. Load all articles (2nd page, 2 items).
     $collection_output = Json::decode($this->drupalGet('/jsonapi/node/article', [
       'query' => [
@@ -74,8 +74,8 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
       ] + $default_sort,
     ]));
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertEquals(2, count($collection_output['data']));
-    $this->assertContains('page%5Boffset%5D=4', $collection_output['links']['next']['href']);
+    $this->assertCount(2, $collection_output['data']);
+    $this->assertStringContainsString('page%5Boffset%5D=4', $collection_output['links']['next']['href']);
     // 5. Single article.
     $uuid = $this->nodes[0]->uuid();
     $single_output = Json::decode($this->drupalGet('/jsonapi/node/article/' . $uuid));
@@ -123,7 +123,7 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
     $this->assertSession()->statusCodeEquals(200);
     $this->assertEquals('taxonomy_term--tags', $single_output['data'][0]['type']);
     $this->assertArrayNotHasKey('tid', $single_output['data'][0]['attributes']);
-    $this->assertContains(
+    $this->assertStringContainsString(
       '/taxonomy_term/tags/',
       $single_output['data'][0]['links']['self']['href']
     );
@@ -189,10 +189,11 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
       'query' => ['page' => ['limit' => 2]] + $default_sort,
     ]));
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertEquals(1, count($single_output['data']));
-    $this->assertEquals(1, count(array_filter(array_keys($single_output['meta']['omitted']['links']), function ($key) {
+    $this->assertCount(1, $single_output['data']);
+    $non_help_links = array_filter(array_keys($single_output['meta']['omitted']['links']), function ($key) {
       return $key !== 'help';
-    })));
+    });
+    $this->assertCount(1, $non_help_links);
     $link_keys = array_keys($single_output['meta']['omitted']['links']);
     $this->assertSame('help', reset($link_keys));
     $this->assertRegExp('/^item--[a-zA-Z0-9]{7}$/', next($link_keys));
@@ -511,7 +512,7 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
       'query' => ['filter' => $filter] + $default_sort,
     ]));
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertEquals(0, count($collection_output['data']));
+    $this->assertCount(0, $collection_output['data']);
   }
 
   /**
@@ -523,7 +524,7 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
     // 1. Load all articles (1st page).
     $collection_output = Json::decode($this->drupalGet('/jsonapi/node/article'));
     $this->assertSession()->statusCodeEquals(200);
-    $this->assertEquals(1, count($collection_output['data']));
+    $this->assertCount(1, $collection_output['data']);
     $this->assertSession()
       ->responseHeaderEquals('Content-Type', 'application/vnd.api+json');
   }
@@ -575,7 +576,7 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
     $this->assertEquals(201, $response->getStatusCode());
     $this->assertArrayNotHasKey('uuid', $created_response['data']['attributes']);
     $uuid = $created_response['data']['id'];
-    $this->assertEquals(2, count($created_response['data']['relationships']['field_tags']['data']));
+    $this->assertCount(2, $created_response['data']['relationships']['field_tags']['data']);
     $this->assertEquals($created_response['data']['links']['self']['href'], $response->getHeader('Location')[0]);
 
     // 2. Authorization error.
@@ -773,7 +774,7 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
     ]);
     $updated_response = Json::decode($response->getBody()->__toString());
     $this->assertEquals(200, $response->getStatusCode());
-    $this->assertEquals(3, count($updated_response['data']));
+    $this->assertCount(3, $updated_response['data']);
     $this->assertEquals('taxonomy_term--tags', $updated_response['data'][2]['type']);
     $this->assertEquals($this->tags[2]->uuid(), $updated_response['data'][2]['id']);
     // 10. Successful PATCH to related endpoint.
@@ -861,7 +862,7 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
         'id' => $uuid,
         'type' => 'node--article',
         'attributes' => [
-          'field_that_doesnt_exist' => 'foobar',
+          'field_that_does_not_exist' => 'foobar',
         ],
       ],
     ];
@@ -875,7 +876,7 @@ class JsonApiFunctionalTest extends JsonApiFunctionalTestBase {
     ]);
     $updated_response = Json::decode($response->getBody()->__toString());
     $this->assertEquals(422, $response->getStatusCode());
-    $this->assertEquals("The attribute field_that_doesnt_exist does not exist on the node--article resource type.",
+    $this->assertEquals("The attribute field_that_does_not_exist does not exist on the node--article resource type.",
       $updated_response['errors']['0']['detail']);
     // 14. Successful DELETE.
     $response = $this->request('DELETE', $individual_url, [
