@@ -26,7 +26,7 @@ class MenuLinkContentTest extends ResourceTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['menu_link_content'];
+  protected static $modules = ['menu_link_content'];
 
   /**
    * {@inheritdoc}
@@ -195,7 +195,7 @@ class MenuLinkContentTest extends ResourceTestBase {
     $this->config('jsonapi.settings')->set('read_only', FALSE)->save(TRUE);
 
     $document = $this->getPostDocument();
-    $document['data']['attributes']['link']['options'] = 'O:44:"Symfony\\Component\\Process\\Pipes\\WindowsPipes":8:{s:51:"\\Symfony\\Component\\Process\\Pipes\\WindowsPipes files";a:1:{i:0;s:3:"foo";}s:57:" Symfony\\Component\\Process\\Pipes\\WindowsPipes fileHandles";a:0:{}s:55:" Symfony\\Component\\Process\\Pipes\\WindowsPipes readBytes";a:2:{i:1;i:0;i:2;i:0;}s:59:" Symfony\\Component\\Process\\Pipes\\WindowsPipes disableOutput";b:0;s:5:"pipes";a:0:{}s:58:" Symfony\\Component\\Process\\Pipes\\AbstractPipes inputBuffer";s:0:"";s:52:" Symfony\\Component\\Process\\Pipes\\AbstractPipes input";N;s:54:" Symfony\\Component\\Process\\Pipes\\AbstractPipes blocked";b:1;}';
+    $document['data']['attributes']['link']['options'] = "O:44:\"Symfony\\Component\\Process\\Pipes\\WindowsPipes\":8:{s:51:\"\\Symfony\\Component\\Process\\Pipes\\WindowsPipes\0files\";a:1:{i:0;s:3:\"foo\";}s:57:\"\0Symfony\\Component\\Process\\Pipes\\WindowsPipes\0fileHandles\";a:0:{}s:55:\"\0Symfony\\Component\\Process\\Pipes\\WindowsPipes\0readBytes\";a:2:{i:1;i:0;i:2;i:0;}s:59:\"\0Symfony\\Component\\Process\\Pipes\\WindowsPipes\0disableOutput\";b:0;s:5:\"pipes\";a:0:{}s:58:\"\0Symfony\\Component\\Process\\Pipes\\AbstractPipes\0inputBuffer\";s:0:\"\";s:52:\"\0Symfony\\Component\\Process\\Pipes\\AbstractPipes\0input\";N;s:54:\"\0Symfony\\Component\\Process\\Pipes\\AbstractPipes\0blocked\";b:1;}";
     $url = Url::fromRoute(sprintf('jsonapi.%s.collection.post', static::$resourceTypeName));
     $request_options = [];
     $request_options[RequestOptions::HEADERS]['Accept'] = 'application/vnd.api+json';
