@@ -35,7 +35,11 @@ class LanguageConfigurationElementTest extends BrowserTestBase {
 
   protected function setUp(): void {
     parent::setUp();
-    $user = $this->drupalCreateUser(['access administration pages', 'administer languages', 'administer content types']);
+    $user = $this->drupalCreateUser([
+      'access administration pages',
+      'administer languages',
+      'administer content types',
+    ]);
     $this->drupalLogin($user);
   }
 
