@@ -2,6 +2,7 @@
 
 namespace Drupal\locale\Form;
 
+use Drupal\Component\Gettext\PoItem;
 use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\Render\Element;
 use Drupal\locale\SourceString;
@@ -186,7 +187,7 @@ class TranslateEditForm extends TranslateFormBase {
       // Plural translations are saved in a delimited string. To be able to
       // compare the new strings with the existing strings a string in the same
       // format is created.
-      $new_translation_string_delimited = implode(LOCALE_PLURAL_DELIMITER, $new_translation['translations']);
+      $new_translation_string_delimited = implode(PoItem::DELIMITER, $new_translation['translations']);
 
       // Generate an imploded string without delimiter, to be able to run
       // empty() on it.
