@@ -21,7 +21,7 @@ class LocaleProjectStorage implements LocaleProjectStorageInterface {
    *
    * @var array
    */
-  protected $cache = array();
+  protected $cache = [];
 
   /**
    * Cache status flag.
@@ -36,7 +36,7 @@ class LocaleProjectStorage implements LocaleProjectStorageInterface {
    * @param \Drupal\Core\KeyValueStore\KeyValueFactoryInterface $key_value_factory
    *   The key value store to use.
    */
-  function __construct(KeyValueFactoryInterface $key_value_factory) {
+  public function __construct(KeyValueFactoryInterface $key_value_factory) {
     $this->keyValueStore = $key_value_factory->get('locale.project');
   }
 
@@ -44,7 +44,7 @@ class LocaleProjectStorage implements LocaleProjectStorageInterface {
    * {@inheritdoc}
    */
   public function get($key, $default = NULL) {
-    $values = $this->getMultiple(array($key));
+    $values = $this->getMultiple([$key]);
     return isset($values[$key]) ? $values[$key] : $default;
   }
 
@@ -52,8 +52,8 @@ class LocaleProjectStorage implements LocaleProjectStorageInterface {
    * {@inheritdoc}
    */
   public function getMultiple(array $keys) {
-    $values = array();
-    $load = array();
+    $values = [];
+    $load = [];
     foreach ($keys as $key) {
       // Check if we have a value in the cache.
       if (isset($this->cache[$key])) {
@@ -87,7 +87,7 @@ class LocaleProjectStorage implements LocaleProjectStorageInterface {
    * {@inheritdoc}
    */
   public function set($key, $value) {
-    $this->setMultiple(array($key => $value));
+    $this->setMultiple([$key => $value]);
   }
 
   /**
@@ -104,7 +104,7 @@ class LocaleProjectStorage implements LocaleProjectStorageInterface {
    * {@inheritdoc}
    */
   public function delete($key) {
-    $this->deleteMultiple(array($key));
+    $this->deleteMultiple([$key]);
   }
 
   /**
@@ -121,7 +121,7 @@ class LocaleProjectStorage implements LocaleProjectStorageInterface {
    * {@inheritdoc}
    */
   public function resetCache() {
-    $this->cache = array();
+    $this->cache = [];
     static::$all = FALSE;
   }
 
@@ -165,4 +165,5 @@ class LocaleProjectStorage implements LocaleProjectStorageInterface {
     }
     return $this->cache;
   }
+
 }
