@@ -330,8 +330,12 @@ abstract class MediaSourceBase extends PluginBase implements MediaSourceInterfac
       throw new \RuntimeException('Source field for media source is not defined.');
     }
 
-    /** @var \Drupal\Core\Field\FieldItemInterface $field_item */
-    $field_item = $media->get($source_field)->first();
+    $items = $media->get($source_field);
+    if ($items->isEmpty()) {
+      return NULL;
+    }
+
+    $field_item = $items->first();
     return $field_item->{$field_item->mainPropertyName()};
   }
 
