@@ -14,7 +14,7 @@ class MediaJsonBasicAuthTest extends MediaResourceTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['basic_auth'];
+  protected static $modules = ['basic_auth'];
 
   /**
    * {@inheritdoc}
