@@ -85,26 +85,6 @@ interface MigrateIdMapInterface extends \Iterator, PluginInspectionInterface {
    */
   public function getMessages(array $source_id_values = [], $level = NULL);
 
-  /**
-   * Retrieves an iterator over messages relate to source records.
-   *
-   * @param array $source_id_values
-   *   (optional) The source identifier keyed values of the record, e.g.
-   *   ['nid' => 5]. If empty (the default), all messages are retrieved.
-   * @param int $level
-   *   (optional) Message severity. If NULL (the default), retrieve messages of
-   *   all severities.
-   *
-   * @return \Iterator
-   *   Retrieves an iterator over the message rows.
-   *
-   * @deprecated in drupal:8.8.0 and is removed from drupal:9.0.0.
-   *   Use \Drupal\migrate\Plugin\MigrateIdMapInterface::getMessages() instead.
-   *
-   * @see https://www.drupal.org/node/3060969
-   */
-  public function getMessageIterator(array $source_id_values = [], $level = NULL);
-
   /**
    * Prepares to run a full update.
    *
@@ -226,25 +206,6 @@ interface MigrateIdMapInterface extends \Iterator, PluginInspectionInterface {
    */
   public function lookupSourceId(array $destination_id_values);
 
-  /**
-   * Looks up the destination identifier corresponding to a source key.
-   *
-   * Given a (possibly multi-field) source identifier value, return the
-   * (possibly multi-field) destination identifier value it is mapped to.
-   *
-   * @param array $source_id_values
-   *   The source identifier keyed values of the record, e.g. ['nid' => 5].
-   *
-   * @return array
-   *   The destination identifier values of the record, or empty on failure.
-   *
-   * @deprecated in drupal:8.1.0 and is removed from drupal:9.0.0. Use
-   *   lookupDestinationIds() instead.
-   *
-   * @see https://www.drupal.org/node/2725809
-   */
-  public function lookupDestinationId(array $source_id_values);
-
   /**
    * Looks up the destination identifiers corresponding to a source key.
    *
