@@ -50,9 +50,19 @@ class NodeAccessGrantsCacheContextTest extends NodeTestBase {
 
     // Create user with simple node access permission. The 'node test view'
     // permission is implemented and granted by the node_access_test module.
-    $this->accessUser = $this->drupalCreateUser(['access content overview', 'access content', 'node test view']);
-    $this->noAccessUser = $this->drupalCreateUser(['access content overview', 'access content']);
-    $this->noAccessUser2 = $this->drupalCreateUser(['access content overview', 'access content']);
+    $this->accessUser = $this->drupalCreateUser([
+      'access content overview',
+      'access content',
+      'node test view',
+    ]);
+    $this->noAccessUser = $this->drupalCreateUser([
+      'access content overview',
+      'access content',
+    ]);
+    $this->noAccessUser2 = $this->drupalCreateUser([
+      'access content overview',
+      'access content',
+    ]);
 
     $this->userMapping = [
       1 => $this->rootUser,
