@@ -35,7 +35,10 @@ class NodeCreationTest extends NodeTestBase {
   protected function setUp(): void {
     parent::setUp();
 
-    $web_user = $this->drupalCreateUser(['create page content', 'edit own page content']);
+    $web_user = $this->drupalCreateUser([
+      'create page content',
+      'edit own page content',
+    ]);
     $this->drupalLogin($web_user);
   }
 
@@ -83,7 +86,10 @@ class NodeCreationTest extends NodeTestBase {
     $this->assertText($this->container->get('date.formatter')->format($node->getCreatedTime()));
 
     // Check if the node revision checkbox is not rendered on node creation form.
-    $admin_user = $this->drupalCreateUser(['administer nodes', 'create page content']);
+    $admin_user = $this->drupalCreateUser([
+      'administer nodes',
+      'create page content',
+    ]);
     $this->drupalLogin($admin_user);
     $this->drupalGet('node/add/page');
     $this->assertNoFieldById('edit-revision', NULL, 'The revision checkbox is not present.');
@@ -231,7 +237,10 @@ class NodeCreationTest extends NodeTestBase {
    * Tests the author autocompletion textfield.
    */
   public function testAuthorAutocomplete() {
-    $admin_user = $this->drupalCreateUser(['administer nodes', 'create page content']);
+    $admin_user = $this->drupalCreateUser([
+      'administer nodes',
+      'create page content',
+    ]);
     $this->drupalLogin($admin_user);
 
     $this->drupalGet('node/add/page');
@@ -239,7 +248,11 @@ class NodeCreationTest extends NodeTestBase {
     $result = $this->xpath('//input[@id="edit-uid-0-value" and contains(@data-autocomplete-path, "user/autocomplete")]');
     $this->assertCount(0, $result, 'No autocompletion without access user profiles.');
 
-    $admin_user = $this->drupalCreateUser(['administer nodes', 'create page content', 'access user profiles']);
+    $admin_user = $this->drupalCreateUser([
+      'administer nodes',
+      'create page content',
+      'access user profiles',
+    ]);
     $this->drupalLogin($admin_user);
 
     $this->drupalGet('node/add/page');
@@ -264,7 +277,9 @@ class NodeCreationTest extends NodeTestBase {
     $this->drupalGet('node/add');
     $this->assertSession()->statusCodeEquals(403);
 
-    $admin_content_types = $this->drupalCreateUser(['administer content types']);
+    $admin_content_types = $this->drupalCreateUser([
+      'administer content types',
+    ]);
     $this->drupalLogin($admin_content_types);
 
     $this->drupalGet('node/add');
