@@ -41,12 +41,18 @@ class NodeRevisionsTest extends NodeTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['node', 'contextual', 'datetime', 'language', 'content_translation'];
+  protected static $modules = [
+    'node',
+    'contextual',
+    'datetime',
+    'language',
+    'content_translation',
+  ];
 
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // Enable additional languages.
@@ -245,17 +251,17 @@ class NodeRevisionsTest extends NodeTestBase {
 
     $this->drupalGet("node/" . $node->id() . "/revisions");
     // Verify revisions is accessible since the type has revisions enabled.
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     // Check initial revision is shown on the node revisions overview page.
     $this->assertText('Simple revision message (EN)');
 
     // Verify that delete operation is inaccessible for the default revision.
     $this->drupalGet("node/" . $node->id() . "/revisions/" . $node->getRevisionId() . "/delete");
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
 
     // Verify that revert operation is inaccessible for the default revision.
     $this->drupalGet("node/" . $node->id() . "/revisions/" . $node->getRevisionId() . "/revert");
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
 
     // Create a new revision and new log message.
     $node = Node::load($node->id());
@@ -278,7 +284,7 @@ class NodeRevisionsTest extends NodeTestBase {
 
     $this->drupalGet("node/" . $node->id() . "/revisions");
     // Verify revisions is accessible since the type has revisions enabled.
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     // Check initial revision is shown on the node revisions overview page.
     $this->assertText('Simple revision message (EN)');
 
