@@ -46,7 +46,15 @@ class NodeTranslationUITest extends ContentTranslationUITestBase {
    *
    * @var array
    */
-  public static $modules = ['block', 'language', 'content_translation', 'node', 'datetime', 'field_ui', 'help'];
+  protected static $modules = [
+    'block',
+    'language',
+    'content_translation',
+    'node',
+    'datetime',
+    'field_ui',
+    'help',
+  ];
 
   /**
    * The profile to install as a basis for testing.
@@ -55,7 +63,7 @@ class NodeTranslationUITest extends ContentTranslationUITestBase {
    */
   protected $profile = 'standard';
 
-  protected function setUp() {
+  protected function setUp(): void {
     $this->entityTypeId = 'node';
     $this->bundle = 'article';
     parent::setUp();
@@ -253,7 +261,7 @@ class NodeTranslationUITest extends ContentTranslationUITestBase {
     $this->assertNoRaw('core/themes/seven/css/base/elements.css', 'Translation uses frontend theme if edit is frontend.');
 
     // Assert presence of translation page itself (vs. DisabledBundle below).
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
   }
 
   /**
@@ -272,11 +280,11 @@ class NodeTranslationUITest extends ContentTranslationUITestBase {
 
     // Make sure that nothing was inserted into the {content_translation} table.
     $rows = Database::getConnection()->query('SELECT nid, count(nid) AS count FROM {node_field_data} WHERE type <> :type GROUP BY nid HAVING count(nid) >= 2', [':type' => $this->bundle])->fetchAll();
-    $this->assertEqual(0, count($rows));
+    $this->assertCount(0, $rows);
 
     // Ensure the translation tab is not accessible.
     $this->drupalGet('node/' . $node->id() . '/translations');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
   }
 
   /**
@@ -492,7 +500,7 @@ class NodeTranslationUITest extends ContentTranslationUITestBase {
     // Should be different from regular node URL.
     $this->assertNotIdentical($original_revision_url, $original_revision->toUrl()->toString());
     $this->drupalGet($original_revision_url);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Contents should be in English, of correct revision.
     $this->assertText('First rev en title');
@@ -505,7 +513,7 @@ class NodeTranslationUITest extends ContentTranslationUITestBase {
     $this->assertNotIdentical($url_fr, $original_revision->toUrl()->toString());
     $this->assertNotIdentical($url_fr, $original_revision_url);
     $this->drupalGet($url_fr);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Contents should be in French, of correct revision.
     $this->assertText('First rev fr title');
