@@ -18,7 +18,7 @@ class NodeAccessRecordsTest extends NodeAccessTestBase {
    *
    * @var array
    */
-  public static $modules = ['node_test'];
+  protected static $modules = ['node_test'];
 
   /**
    * Creates a node and tests the creation of node access rules.
@@ -31,7 +31,7 @@ class NodeAccessRecordsTest extends NodeAccessTestBase {
     // Check to see if grants added by node_test_node_access_records made it in.
     $connection = Database::getConnection();
     $records = $connection->query('SELECT realm, gid FROM {node_access} WHERE nid = :nid', [':nid' => $node1->id()])->fetchAll();
-    $this->assertEqual(count($records), 1, 'Returned the correct number of rows.');
+    $this->assertCount(1, $records, 'Returned the correct number of rows.');
     $this->assertEqual($records[0]->realm, 'test_article_realm', 'Grant with article_realm acquired for node without alteration.');
     $this->assertEqual($records[0]->gid, 1, 'Grant with gid = 1 acquired for node without alteration.');
 
@@ -41,7 +41,7 @@ class NodeAccessRecordsTest extends NodeAccessTestBase {
 
     // Check to see if grants added by node_test_node_access_records made it in.
     $records = $connection->query('SELECT realm, gid FROM {node_access} WHERE nid = :nid', [':nid' => $node2->id()])->fetchAll();
-    $this->assertEqual(count($records), 1, 'Returned the correct number of rows.');
+    $this->assertCount(1, $records, 'Returned the correct number of rows.');
     $this->assertEqual($records[0]->realm, 'test_page_realm', 'Grant with page_realm acquired for node without alteration.');
     $this->assertEqual($records[0]->gid, 1, 'Grant with gid = 1 acquired for node without alteration.');
 
@@ -51,7 +51,7 @@ class NodeAccessRecordsTest extends NodeAccessTestBase {
 
     // Check to see if grants added by node_test_node_access_records made it in.
     $records = $connection->query('SELECT realm, gid FROM {node_access} WHERE nid = :nid', [':nid' => $node3->id()])->fetchAll();
-    $this->assertEqual(count($records), 1, 'Returned the correct number of rows.');
+    $this->assertCount(1, $records, 'Returned the correct number of rows.');
     $this->assertEqual($records[0]->realm, 'test_page_realm', 'Grant with page_realm acquired for node without alteration.');
     $this->assertEqual($records[0]->gid, 1, 'Grant with gid = 1 acquired for node without alteration.');
 
@@ -62,7 +62,7 @@ class NodeAccessRecordsTest extends NodeAccessTestBase {
     // Check to see if grant added by node_test_node_access_records was altered
     // by node_test_node_access_records_alter.
     $records = $connection->query('SELECT realm, gid FROM {node_access} WHERE nid = :nid', [':nid' => $node4->id()])->fetchAll();
-    $this->assertEqual(count($records), 1, 'Returned the correct number of rows.');
+    $this->assertCount(1, $records, 'Returned the correct number of rows.');
     $this->assertEqual($records[0]->realm, 'test_alter_realm', 'Altered grant with alter_realm acquired for node.');
     $this->assertEqual($records[0]->gid, 2, 'Altered grant with gid = 2 acquired for node.');
 
@@ -81,7 +81,7 @@ class NodeAccessRecordsTest extends NodeAccessTestBase {
     // empty $grants array is returned.
     $node6 = $this->drupalCreateNode(['status' => 0, 'disable_node_access' => TRUE]);
     $records = $connection->query('SELECT realm, gid FROM {node_access} WHERE nid = :nid', [':nid' => $node6->id()])->fetchAll();
-    $this->assertEqual(count($records), 0, 'Returned no records for unpublished node.');
+    $this->assertCount(0, $records, 'Returned no records for unpublished node.');
   }
 
 }
