@@ -2,7 +2,6 @@
 
 namespace Drupal\options\Plugin\Field\FieldType;
 
-use Drupal\Core\Field\AllowedTagsXssTrait;
 use Drupal\Core\Field\FieldDefinitionInterface;
 use Drupal\Core\Field\FieldItemBase;
 use Drupal\Core\Form\FormStateInterface;
@@ -15,8 +14,6 @@ use Drupal\Core\TypedData\OptionsProviderInterface;
  */
 abstract class ListItemBase extends FieldItemBase implements OptionsProviderInterface {
 
-  use AllowedTagsXssTrait;
-
   /**
    * {@inheritdoc}
    */
