@@ -22,7 +22,6 @@ use Drupal\rest\RestResourceConfigInterface;
  *   ),
  *   config_prefix = "resource",
  *   admin_permission = "administer rest resources",
- *   label_callback = "getLabelFromPlugin",
  *   entity_keys = {
  *     "id" = "id"
  *   },
@@ -88,17 +87,6 @@ class RestResourceConfig extends ConfigEntityBase implements RestResourceConfigI
     }
   }
 
-  /**
-   * The label callback for this configuration entity.
-   *
-   * @return string The label.
-   */
-  protected function getLabelFromPlugin() {
-    $plugin_definition = $this->getResourcePluginManager()
-      ->getDefinition(['id' => $this->plugin_id]);
-    return $plugin_definition['label'];
-  }
-
   /**
    * Returns the resource plugin manager.
    *
@@ -125,8 +113,10 @@ class RestResourceConfig extends ConfigEntityBase implements RestResourceConfigI
     switch ($this->granularity) {
       case RestResourceConfigInterface::METHOD_GRANULARITY:
         return $this->getMethodsForMethodGranularity();
+
       case RestResourceConfigInterface::RESOURCE_GRANULARITY:
         return $this->configuration['methods'];
+
       default:
         throw new \InvalidArgumentException('Invalid granularity specified.');
     }
@@ -150,8 +140,10 @@ class RestResourceConfig extends ConfigEntityBase implements RestResourceConfigI
     switch ($this->granularity) {
       case RestResourceConfigInterface::METHOD_GRANULARITY:
         return $this->getAuthenticationProvidersForMethodGranularity($method);
+
       case RestResourceConfigInterface::RESOURCE_GRANULARITY:
         return $this->configuration['authentication'];
+
       default:
         throw new \InvalidArgumentException('Invalid granularity specified.');
     }
@@ -181,8 +173,10 @@ class RestResourceConfig extends ConfigEntityBase implements RestResourceConfigI
     switch ($this->granularity) {
       case RestResourceConfigInterface::METHOD_GRANULARITY:
         return $this->getFormatsForMethodGranularity($method);
+
       case RestResourceConfigInterface::RESOURCE_GRANULARITY:
         return $this->configuration['formats'];
+
       default:
         throw new \InvalidArgumentException('Invalid granularity specified.');
     }
@@ -215,7 +209,7 @@ class RestResourceConfig extends ConfigEntityBase implements RestResourceConfigI
   }
 
   /**
-   * (@inheritdoc)
+   * {@inheritdoc}
    */
   public function calculateDependencies() {
     parent::calculateDependencies();
