@@ -2,16 +2,17 @@
 
 namespace Drupal\Tests\rest\Kernel;
 
-use Drupal\Core\Config\ConfigFactoryInterface;
-use Drupal\Core\Config\ImmutableConfig;
+use Drupal\Component\Serialization\Json;
 use Drupal\Core\Routing\RouteMatch;
 use Drupal\KernelTests\KernelTestBase;
 use Drupal\rest\Plugin\ResourceBase;
 use Drupal\rest\RequestHandler;
 use Drupal\rest\ResourceResponse;
 use Drupal\rest\RestResourceConfigInterface;
+use Prophecy\Argument;
 use Symfony\Component\HttpFoundation\Request;
 use Symfony\Component\Routing\Route;
+use Symfony\Component\Serializer\Encoder\DecoderInterface;
 use Symfony\Component\Serializer\SerializerInterface;
 
 /**
@@ -27,7 +28,7 @@ class RequestHandlerTest extends KernelTestBase {
    */
   protected $requestHandler;
 
-  public static $modules = ['serialization', 'rest'];
+  protected static $modules = ['serialization', 'rest'];
 
   /**
    * The entity storage.
@@ -39,24 +40,27 @@ class RequestHandlerTest extends KernelTestBase {
   /**
    * {@inheritdoc}
    */
-  public function setUp() {
+  public function setUp(): void {
     parent::setUp();
-    $config_factory = $this->prophesize(ConfigFactoryInterface::class);
-    $config_factory->get('rest.settings')
-      ->willReturn($this->prophesize(ImmutableConfig::class)->reveal());
     $serializer = $this->prophesize(SerializerInterface::class);
-    $this->requestHandler = new RequestHandler($config_factory->reveal(), $serializer->reveal());
+    $serializer->willImplement(DecoderInterface::class);
+    $serializer->decode(Json::encode(['this is an array']), NULL, Argument::type('array'))
+      ->willReturn(['this is an array']);
+    $this->requestHandler = new RequestHandler($serializer->reveal());
   }
 
   /**
    * @covers ::handle
    */
   public function testHandle() {
-    $request = new Request();
-    $route_match = new RouteMatch('test', (new Route('/rest/test', ['_rest_resource_config' => 'restplugin'], ['_format' => 'json']))->setMethods(['GET']));
+    $request = new Request([], [], [], [], [], [], Json::encode(['this is an array']));
+    $route_match = new RouteMatch('test', (new Route('/rest/test', ['_rest_resource_config' => 'restplugin', 'example' => ''], ['_format' => 'json']))->setMethods(['GET']));
 
     $resource = $this->prophesize(StubRequestHandlerResourcePlugin::class);
-    $resource->get(NULL, $request)
+    $resource->get('', $request)
+      ->shouldBeCalled();
+    $resource->getPluginDefinition()
+      ->willReturn([])
       ->shouldBeCalled();
 
     // Setup the configuration.
@@ -79,10 +83,10 @@ class RequestHandlerTest extends KernelTestBase {
     $this->assertEquals($response, $handler_response);
 
     // We will call the patch method this time.
-    $route_match = new RouteMatch('test', (new Route('/rest/test', ['_rest_resource_config' => 'restplugin'], ['_content_type_format' => 'json']))->setMethods(['PATCH']));
+    $route_match = new RouteMatch('test', (new Route('/rest/test', ['_rest_resource_config' => 'restplugin', 'example_original' => ''], ['_content_type_format' => 'json']))->setMethods(['PATCH']));
     $request->setMethod('PATCH');
     $response = new ResourceResponse([]);
-    $resource->patch(NULL, $request)
+    $resource->patch(['this is an array'], $request)
       ->shouldBeCalledTimes(1)
       ->willReturn($response);
     $handler_response = $this->requestHandler->handle($route_match, $request, $config->reveal());
@@ -96,11 +100,11 @@ class RequestHandlerTest extends KernelTestBase {
  */
 class StubRequestHandlerResourcePlugin extends ResourceBase {
 
-  public function get($example, Request $request) {}
+  public function get($example = NULL, Request $request = NULL) {}
 
   public function post() {}
 
-  public function patch($example_original, Request $request) {}
+  public function patch($data, Request $request) {}
 
   public function delete() {}
 
