@@ -8,6 +8,8 @@ use Drupal\Core\Url;
 
 /**
  * Provides the search reindex confirmation form.
+ *
+ * @internal
  */
 class ReindexConfirm extends ConfirmFormBase {
 
@@ -63,8 +65,9 @@ class ReindexConfirm extends ConfirmFormBase {
       foreach ($search_page_repository->getIndexableSearchPages() as $entity) {
         $entity->getPlugin()->markForReindex();
       }
-      drupal_set_message($this->t('All search indexes will be rebuilt.'));
+      $this->messenger()->addStatus($this->t('All search indexes will be rebuilt.'));
       $form_state->setRedirectUrl($this->getCancelUrl());
     }
   }
+
 }
