@@ -39,7 +39,11 @@ class SearchPageTextTest extends BrowserTestBase {
     $this->drupalCreateContentType(['type' => 'page', 'name' => 'Basic page']);
 
     // Create user.
-    $this->searchingUser = $this->drupalCreateUser(['search content', 'access user profiles', 'use advanced search']);
+    $this->searchingUser = $this->drupalCreateUser([
+      'search content',
+      'access user profiles',
+      'use advanced search',
+    ]);
     $this->drupalPlaceBlock('local_tasks_block');
     $this->drupalPlaceBlock('page_title_block');
   }
