@@ -22,7 +22,7 @@ class XmlEncoderTest extends UnitTestCase {
   protected $encoder;
 
   /**
-   * @var \Symfony\Component\Serializer\Encoder\XmlEncoder|\PHPUnit_Framework_MockObject_MockObject
+   * @var \Symfony\Component\Serializer\Encoder\XmlEncoder|\PHPUnit\Framework\MockObject\MockObject
    */
   protected $baseEncoder;
 
@@ -33,8 +33,8 @@ class XmlEncoderTest extends UnitTestCase {
    */
   protected $testArray = ['test' => 'test'];
 
-  protected function setUp() {
-    $this->baseEncoder = $this->getMock(BaseXmlEncoder::class);
+  protected function setUp(): void {
+    $this->baseEncoder = $this->createMock(BaseXmlEncoder::class);
     $this->encoder = new XmlEncoder();
     $this->encoder->setBaseEncoder($this->baseEncoder);
   }
@@ -97,6 +97,7 @@ class XmlEncoderTest extends UnitTestCase {
 }
 
 class TestObject {
+
   public function getA() {
     return 'A';
   }
