@@ -21,13 +21,13 @@ class TypedDataNormalizerTest extends UnitTestCase {
   /**
    * The mock typed data instance.
    *
-   * @var \Drupal\Core\TypedData\TypedDataInterface|\PHPUnit_Framework_MockObject_MockObject
+   * @var \Drupal\Core\TypedData\TypedDataInterface|\PHPUnit\Framework\MockObject\MockObject
    */
   protected $typedData;
 
-  protected function setUp() {
+  protected function setUp(): void {
     $this->normalizer = new TypedDataNormalizer();
-    $this->typedData = $this->getMock('Drupal\Core\TypedData\TypedDataInterface');
+    $this->typedData = $this->createMock('Drupal\Core\TypedData\TypedDataInterface');
   }
 
   /**
