@@ -67,7 +67,7 @@ class AjaxFormsTestValidationForm extends FormBase {
    * {@inheritdoc}
    */
   public function submitForm(array &$form, FormStateInterface $form_state) {
-    drupal_set_message($this->t("Validation form submitted"));
+    $this->messenger()->addStatus($this->t("Validation form submitted"));
   }
 
 }
