@@ -3,7 +3,7 @@
  *  Testing behavior for JSWebAssertTest.
  */
 
-(function ($, Drupal, drupalSettings) {
+(function($, Drupal, drupalSettings) {
   /**
    * @type {Drupal~behavior}
    *
@@ -12,7 +12,9 @@
    */
   Drupal.behaviors.js_webassert_test_wait_for_ajax_request = {
     attach(context) {
-      $('input[name="test_assert_wait_on_ajax_input"]').val('js_webassert_test');
+      $('input[name="test_assert_wait_on_ajax_input"]').val(
+        'js_webassert_test',
+      );
     },
   };
-}(jQuery, Drupal, drupalSettings));
+})(jQuery, Drupal, drupalSettings);
