@@ -16,12 +16,17 @@ class DrupalDateTimeTest extends BrowserTestBase {
   /**
    * Set up required modules.
    */
-  public static $modules = [];
+  protected static $modules = [];
+
+  /**
+   * {@inheritdoc}
+   */
+  protected $defaultTheme = 'stark';
 
   /**
    * Test setup.
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
   }
@@ -33,7 +38,7 @@ class DrupalDateTimeTest extends BrowserTestBase {
     $options = [
       'query' => [
         'date' => 'Tue+Sep+17+2013+21%3A35%3A31+GMT%2B0100+(BST)#',
-      ]
+      ],
     ];
     // Query the AJAX Timezone Callback with a long-format date.
     $response = $this->drupalGet('system/timezone/BST/3600/1', $options);
@@ -88,7 +93,7 @@ class DrupalDateTimeTest extends BrowserTestBase {
     $this->drupalPostForm('user/' . $test_user->id() . '/edit', $edit, t('Save'));
 
     // Reload the user and reset the timezone in AccountProxy::setAccount().
-    \Drupal::entityManager()->getStorage('user')->resetCache();
+    \Drupal::entityTypeManager()->getStorage('user')->resetCache();
     $this->container->get('current_user')->setAccount(User::load($test_user->id()));
 
     // Create a date object with an unspecified timezone, which should
