@@ -15,7 +15,7 @@ class MenuHalJsonAnonTest extends MenuResourceTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['hal'];
+  protected static $modules = ['hal'];
 
   /**
    * {@inheritdoc}
