@@ -18,7 +18,7 @@ class BreadcrumbFrontCacheContextsTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = [
+  protected static $modules = [
     'block',
     'node',
     'path',
@@ -40,7 +40,7 @@ class BreadcrumbFrontCacheContextsTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalPlaceBlock('system_breadcrumb_block');
@@ -89,7 +89,7 @@ class BreadcrumbFrontCacheContextsTest extends BrowserTestBase {
     $this->drupalGet($this->nodeWithAlias->path->alias);
     $breadcrumbs = $this->assertSession()->elementExists('css', '.block-system-breadcrumb-block');
     $crumbs = $breadcrumbs->findAll('css', 'ol li');
-    $this->assertTrue(count($crumbs) === 1);
+    $this->assertCount(1, $crumbs);
     $this->assertTrue($crumbs[0]->getText() === 'Home');
   }
 
