@@ -15,7 +15,7 @@ class MenuLinkSecurityTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['menu_link_content', 'block', 'menu_test'];
+  protected static $modules = ['menu_link_content', 'block', 'menu_test'];
 
   /**
    * {@inheritdoc}
