@@ -19,7 +19,7 @@ class InstallTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['module_test'];
+  protected static $modules = ['module_test'];
 
   /**
    * {@inheritdoc}
@@ -58,7 +58,7 @@ class InstallTest extends BrowserTestBase {
 
     $post_update_key_value = \Drupal::keyValue('post_update');
     $existing_updates = $post_update_key_value->get('existing_updates', []);
-    $this->assertTrue(in_array('module_test_post_update_test', $existing_updates));
+    $this->assertContains('module_test_post_update_test', $existing_updates);
   }
 
   /**
@@ -69,7 +69,7 @@ class InstallTest extends BrowserTestBase {
 
     $post_update_key_value = \Drupal::keyValue('post_update');
     $existing_updates = $post_update_key_value->get('existing_updates', []);
-    $this->assertFalse(in_array('module_test_post_update_test', $existing_updates));
+    $this->assertNotContains('module_test_post_update_test', $existing_updates);
   }
 
   /**
