@@ -17,7 +17,7 @@ class ErrorHandlerTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['error_test'];
+  protected static $modules = ['error_test'];
 
   /**
    * {@inheritdoc}
@@ -51,7 +51,7 @@ class ErrorHandlerTest extends BrowserTestBase {
     // Set error reporting to display verbose notices.
     $this->config('system.logging')->set('error_level', ERROR_REPORTING_DISPLAY_VERBOSE)->save();
     $this->drupalGet('error-test/generate-warnings');
-    $this->assertResponse(200, 'Received expected HTTP status code.');
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertErrorMessage($error_notice);
     $this->assertErrorMessage($error_warning);
     $this->assertErrorMessage($error_user_notice);
@@ -66,7 +66,7 @@ class ErrorHandlerTest extends BrowserTestBase {
     // Set error reporting to collect notices.
     $config->set('error_level', ERROR_REPORTING_DISPLAY_ALL)->save();
     $this->drupalGet('error-test/generate-warnings');
-    $this->assertResponse(200, 'Received expected HTTP status code.');
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertErrorMessage($error_notice);
     $this->assertErrorMessage($error_warning);
     $this->assertErrorMessage($error_user_notice);
@@ -75,7 +75,7 @@ class ErrorHandlerTest extends BrowserTestBase {
     // Set error reporting to not collect notices.
     $config->set('error_level', ERROR_REPORTING_DISPLAY_SOME)->save();
     $this->drupalGet('error-test/generate-warnings');
-    $this->assertResponse(200, 'Received expected HTTP status code.');
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertNoErrorMessage($error_notice);
     $this->assertErrorMessage($error_warning);
     $this->assertErrorMessage($error_user_notice);
@@ -84,7 +84,7 @@ class ErrorHandlerTest extends BrowserTestBase {
     // Set error reporting to not show any errors.
     $config->set('error_level', ERROR_REPORTING_HIDE)->save();
     $this->drupalGet('error-test/generate-warnings');
-    $this->assertResponse(200, 'Received expected HTTP status code.');
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertNoErrorMessage($error_notice);
     $this->assertNoErrorMessage($error_warning);
     $this->assertNoErrorMessage($error_user_notice);
@@ -142,7 +142,7 @@ class ErrorHandlerTest extends BrowserTestBase {
 
     $this->drupalGet('error-test/trigger-exception');
     $this->assertNull($this->drupalGetHeader('X-Drupal-Cache'));
-    $this->assertIdentical(strpos($this->drupalGetHeader('Cache-Control'), 'public'), FALSE, 'Received expected HTTP status line.');
+    $this->assertSession()->responseHeaderNotContains('Cache-Control', 'public');
     $this->assertSession()->statusCodeEquals(500);
     $this->assertNoErrorMessage($error_exception);
   }
