@@ -16,7 +16,7 @@ class StatusTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['update_test_postupdate'];
+  protected static $modules = ['update_test_postupdate'];
 
   /**
    * {@inheritdoc}
@@ -26,7 +26,7 @@ class StatusTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // Unset the sync directory in settings.php to trigger the error.
@@ -48,7 +48,7 @@ class StatusTest extends BrowserTestBase {
   public function testStatusPage() {
     // Go to Administration.
     $this->drupalGet('admin/reports/status');
-    $this->assertResponse(200, 'The status page is reachable.');
+    $this->assertSession()->statusCodeEquals(200);
 
     $phpversion = phpversion();
     $this->assertText($phpversion, 'Php version is shown on the page.');
@@ -63,7 +63,7 @@ class StatusTest extends BrowserTestBase {
     // If a module is fully installed no pending updates exists.
     $this->assertNoText(t('Out of date'));
 
-    // The global $config_directories is not properly formed.
+    // The setting config_sync_directory is not properly formed.
     $this->assertRaw(t("Your %file file must define the %setting setting", ['%file' => $this->siteDirectory . '/settings.php', '%setting' => "\$settings['config_sync_directory']"]));
 
     // Set the schema version of update_test_postupdate to a lower version, so
@@ -81,7 +81,7 @@ class StatusTest extends BrowserTestBase {
     $this->assertText(t('Out of date'));
 
     $this->drupalGet('admin/reports/status/php');
-    $this->assertResponse(200, 'The phpinfo page is reachable.');
+    $this->assertSession()->statusCodeEquals(200);
 
     // Check if cron error is displayed in errors section
     $cron_last_run = \Drupal::state()->get('system.cron_last');
