@@ -8,6 +8,8 @@ use Drupal\Core\Form\FormStateInterface;
 use Drupal\Core\Link;
 use Drupal\Core\State\StateInterface;
 use Drupal\Core\Url;
+use Drupal\update\UpdateFetcherInterface;
+use Drupal\update\UpdateManagerInterface;
 use Drupal\update\ModuleVersion;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
@@ -104,7 +106,7 @@ class UpdateManagerUpdate extends FormBase {
     $project_data = update_calculate_project_data($available);
     foreach ($project_data as $name => $project) {
       // Filter out projects which are up to date already.
-      if ($project['status'] == UPDATE_CURRENT) {
+      if ($project['status'] == UpdateManagerInterface::CURRENT) {
         continue;
       }
       // The project name to display can vary based on the info we have.
@@ -160,23 +162,23 @@ class UpdateManagerUpdate extends FormBase {
       ];
 
       switch ($project['status']) {
-        case UPDATE_NOT_SECURE:
-        case UPDATE_REVOKED:
+        case UpdateManagerInterface::NOT_SECURE:
+        case UpdateManagerInterface::REVOKED:
           $entry['title'] .= ' ' . $this->t('(Security update)');
           $entry['#weight'] = -2;
           $type = 'security';
           break;
 
-        case UPDATE_NOT_SUPPORTED:
+        case UpdateManagerInterface::NOT_SUPPORTED:
           $type = 'unsupported';
           $entry['title'] .= ' ' . $this->t('(Unsupported)');
           $entry['#weight'] = -1;
           break;
 
-        case UPDATE_UNKNOWN:
-        case UPDATE_NOT_FETCHED:
-        case UPDATE_NOT_CHECKED:
-        case UPDATE_NOT_CURRENT:
+        case UpdateFetcherInterface::UNKNOWN:
+        case UpdateFetcherInterface::NOT_FETCHED:
+        case UpdateFetcherInterface::NOT_CHECKED:
+        case UpdateManagerInterface::NOT_CURRENT:
           $type = 'recommended';
           break;
 
