@@ -3,6 +3,7 @@
 namespace Drupal\views\Plugin\views\sort;
 
 use Drupal\Core\Cache\CacheableDependencyInterface;
+use Drupal\Core\Cache\UncacheableDependencyTrait;
 use Drupal\Core\Form\FormStateInterface;
 
 /**
@@ -12,6 +13,8 @@ use Drupal\Core\Form\FormStateInterface;
  */
 class Random extends SortPluginBase implements CacheableDependencyInterface {
 
+  use UncacheableDependencyTrait;
+
   /**
    * {@inheritdoc}
    */
@@ -28,25 +31,4 @@ class Random extends SortPluginBase implements CacheableDependencyInterface {
     $form['order']['#access'] = FALSE;
   }
 
-  /**
-   * {@inheritdoc}
-   */
-  public function getCacheMaxAge() {
-    return 0;
-  }
-
-  /**
-   * {@inheritdoc}
-   */
-  public function getCacheContexts() {
-    return [];
-  }
-
-  /**
-   * {@inheritdoc}
-   */
-  public function getCacheTags() {
-    return [];
-  }
-
 }
