@@ -36,7 +36,10 @@ class NumericFormatPluralTest extends ViewTestBase {
   protected function setUp($import_test_views = TRUE): void {
     parent::setUp($import_test_views);
 
-    $web_user = $this->drupalCreateUser(['administer views', 'administer languages']);
+    $web_user = $this->drupalCreateUser([
+      'administer views',
+      'administer languages',
+    ]);
     $this->drupalLogin($web_user);
   }
 
