@@ -26,12 +26,12 @@ class ComputedFieldTest extends ViewsKernelTestBase {
    *
    * @var array
    */
-  public static $modules = ['entity_test'];
+  protected static $modules = ['entity_test'];
 
   /**
    * {@inheritdoc}
    */
-  protected function setUp($import_test_views = TRUE) {
+  protected function setUp($import_test_views = TRUE): void {
     parent::setUp($import_test_views);
 
     $this->installEntitySchema('entity_test_computed_field');
@@ -50,7 +50,7 @@ class ComputedFieldTest extends ViewsKernelTestBase {
 
     $rendered_view = $view->preview();
     $output = $this->container->get('renderer')->renderRoot($rendered_view);
-    $this->assertContains('computed string', (string) $output);
+    $this->assertStringContainsString('computed string', (string) $output);
   }
 
 }
