@@ -21,7 +21,14 @@ class ExposedFormUITest extends UITestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['node', 'views_ui', 'block', 'taxonomy', 'field_ui', 'datetime'];
+  protected static $modules = [
+    'node',
+    'views_ui',
+    'block',
+    'taxonomy',
+    'field_ui',
+    'datetime',
+  ];
 
   /**
    * {@inheritdoc}
@@ -37,7 +44,7 @@ class ExposedFormUITest extends UITestBase {
    */
   protected $groupFormUiErrors = [];
 
-  protected function setUp($import_test_views = TRUE) {
+  protected function setUp($import_test_views = TRUE): void {
     parent::setUp($import_test_views);
 
     $this->drupalCreateContentType(['type' => 'article']);
@@ -292,7 +299,7 @@ class ExposedFormUITest extends UITestBase {
     $this->drupalPostForm(NULL, $edit, t('Apply'));
     // Check that the view is saved without errors.
     $this->drupalPostForm(NULL, [], t('Save'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Click the Expose filter button.
     $this->drupalPostForm('admin/structure/views/nojs/add-handler/test_exposed_admin_ui/default/filter', ['name[node_field_data.status]' => 1], t('Add and configure filter criteria'));
@@ -313,7 +320,7 @@ class ExposedFormUITest extends UITestBase {
     $this->drupalPostForm(NULL, $edit, t('Apply'));
     // Check that the view is saved without errors.
     $this->drupalPostForm(NULL, [], t('Save'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     $this->drupalGet('admin/structure/views/nojs/handler/test_exposed_admin_ui/default/filter/status');
     // Assert the same settings defined before still are there.
