@@ -2,7 +2,6 @@
 
 namespace Drupal\Tests\workspaces\Functional\EntityResource;
 
-use Drupal\Tests\rest\Functional\BcTimestampNormalizerUnixTestTrait;
 use Drupal\Tests\rest\Functional\EntityResource\EntityResourceTestBase;
 use Drupal\user\Entity\User;
 use Drupal\workspaces\Entity\Workspace;
@@ -12,12 +11,10 @@ use Drupal\workspaces\Entity\Workspace;
  */
 abstract class WorkspaceResourceTestBase extends EntityResourceTestBase {
 
-  use BcTimestampNormalizerUnixTestTrait;
-
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['workspaces'];
+  protected static $modules = ['workspaces'];
 
   /**
    * {@inheritdoc}
@@ -31,6 +28,13 @@ abstract class WorkspaceResourceTestBase extends EntityResourceTestBase {
     'changed' => NULL,
   ];
 
+  /**
+   * {@inheritdoc}
+   */
+  protected static $uniqueFieldNames = [
+    'id',
+  ];
+
   /**
    * {@inheritdoc}
    */
@@ -49,12 +53,15 @@ abstract class WorkspaceResourceTestBase extends EntityResourceTestBase {
       case 'GET':
         $this->grantPermissionsToTestedRole(['view any workspace']);
         break;
+
       case 'POST':
         $this->grantPermissionsToTestedRole(['create workspace']);
         break;
+
       case 'PATCH':
         $this->grantPermissionsToTestedRole(['edit any workspace']);
         break;
+
       case 'DELETE':
         $this->grantPermissionsToTestedRole(['delete any workspace']);
         break;
@@ -91,10 +98,16 @@ abstract class WorkspaceResourceTestBase extends EntityResourceTestBase {
     $author = User::load($this->entity->getOwnerId());
     return [
       'created' => [
-        $this->formatExpectedTimestampItemValues((int) $this->entity->getCreatedTime()),
+        [
+          'value' => (new \DateTime())->setTimestamp((int) $this->entity->getCreatedTime())->setTimezone(new \DateTimeZone('UTC'))->format(\DateTime::RFC3339),
+          'format' => \DateTime::RFC3339,
+        ],
       ],
       'changed' => [
-        $this->formatExpectedTimestampItemValues($this->entity->getChangedTime()),
+        [
+          'value' => (new \DateTime())->setTimestamp($this->entity->getChangedTime())->setTimezone(new \DateTimeZone('UTC'))->format(\DateTime::RFC3339),
+          'format' => \DateTime::RFC3339,
+        ],
       ],
       'id' => [
         [
@@ -173,23 +186,19 @@ abstract class WorkspaceResourceTestBase extends EntityResourceTestBase {
    * {@inheritdoc}
    */
   protected function getExpectedUnauthorizedAccessMessage($method) {
-    if ($this->config('rest.settings')->get('bc_entity_resource_permissions')) {
-      return parent::getExpectedUnauthorizedAccessMessage($method);
-    }
-
     switch ($method) {
       case 'GET':
         return "The 'view any workspace' permission is required.";
-      break;
+
       case 'POST':
         return "The 'create workspace' permission is required.";
-      break;
+
       case 'PATCH':
         return "The 'edit any workspace' permission is required.";
-      break;
+
       case 'DELETE':
         return "The 'delete any workspace' permission is required.";
-      break;
+
     }
     return parent::getExpectedUnauthorizedAccessMessage($method);
   }
