@@ -20,7 +20,7 @@ class WorkspaceCacheContextTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['block', 'node', 'workspaces'];
+  protected static $modules = ['block', 'node', 'workspaces'];
 
   /**
    * {@inheritdoc}
@@ -54,15 +54,15 @@ class WorkspaceCacheContextTest extends BrowserTestBase {
 
     // Render it so the default cache contexts are applied.
     $renderer->renderRoot($build);
-    $this->assertTrue(in_array('workspace', $build['#cache']['contexts'], TRUE));
+    $this->assertContains('workspace', $build['#cache']['contexts']);
 
     $cid_parts = array_merge($build['#cache']['keys'], $cache_contexts_manager->convertTokensToKeys($build['#cache']['contexts'])->getKeys());
-    $this->assertTrue(in_array('[workspace]=live', $cid_parts, TRUE));
+    $this->assertContains('[workspace]=live', $cid_parts);
 
     // Test that a cache entry is created.
     $cid = implode(':', $cid_parts);
     $bin = $build['#cache']['bin'];
-    $this->assertInstanceOf(\stdClass::class, $this->container->get('cache.' . $bin)->get($cid), 'The entity render element has been cached.');
+    $this->assertInstanceOf(\stdClass::class, $this->container->get('cache.' . $bin)->get($cid));
 
     // Switch to the 'stage' workspace and check that the correct workspace
     // cache context is used.
@@ -80,15 +80,15 @@ class WorkspaceCacheContextTest extends BrowserTestBase {
 
     // Render it so the default cache contexts are applied.
     $renderer->renderRoot($build);
-    $this->assertTrue(in_array('workspace', $build['#cache']['contexts'], TRUE));
+    $this->assertContains('workspace', $build['#cache']['contexts']);
 
     $cid_parts = array_merge($build['#cache']['keys'], $cache_contexts_manager->convertTokensToKeys($build['#cache']['contexts'])->getKeys());
-    $this->assertTrue(in_array('[workspace]=stage', $cid_parts, TRUE));
+    $this->assertContains('[workspace]=stage', $cid_parts);
 
     // Test that a cache entry is created.
     $cid = implode(':', $cid_parts);
     $bin = $build['#cache']['bin'];
-    $this->assertInstanceOf(\stdClass::class, $this->container->get('cache.' . $bin)->get($cid), 'The entity render element has been cached.');
+    $this->assertInstanceOf(\stdClass::class, $this->container->get('cache.' . $bin)->get($cid));
   }
 
 }
