@@ -28,12 +28,15 @@ class MinimalTest extends BrowserTestBase {
   public function testMinimal() {
     $this->drupalGet('');
     // Check the login block is present.
-    $this->assertLink(t('Create new account'));
+    $this->assertSession()->linkExists(t('Create new account'));
     $this->assertSession()->statusCodeEquals(200);
 
     // Create a user to test tools and navigation blocks for logged in users
     // with appropriate permissions.
-    $user = $this->drupalCreateUser(['access administration pages', 'administer content types']);
+    $user = $this->drupalCreateUser([
+      'access administration pages',
+      'administer content types',
+    ]);
     $this->drupalLogin($user);
     $this->drupalGet('');
     $this->assertText(t('Tools'));
