@@ -1,6 +1,11 @@
 #!/usr/bin/env php
 <?php
 
+/**
+ * @file
+ * A command line application to import a database generation script.
+ */
+
 use Drupal\Core\Command\DbToolsApplication;
 use Drupal\Core\DrupalKernel;
 use Drupal\Core\Site\Settings;
@@ -14,7 +19,7 @@ if (PHP_SAPI !== 'cli') {
 $autoloader = require __DIR__ . '/../../autoload.php';
 require_once __DIR__ . '/../includes/bootstrap.inc';
 $request = Request::createFromGlobals();
-Settings::initialize(dirname(dirname(__DIR__)), DrupalKernel::findSitePath($request), $autoloader);
+Settings::initialize(dirname(__DIR__, 2), DrupalKernel::findSitePath($request), $autoloader);
 $kernel = DrupalKernel::createFromRequest($request, $autoloader, 'prod')->boot();
 
 // Run the database dump command.
