@@ -20,7 +20,7 @@ if (PHP_SAPI !== 'cli') {
 $autoloader = require __DIR__ . '/../../autoload.php';
 require_once __DIR__ . '/../includes/bootstrap.inc';
 $request = Request::createFromGlobals();
-Settings::initialize(dirname(dirname(__DIR__)), DrupalKernel::findSitePath($request), $autoloader);
+Settings::initialize(dirname(__DIR__, 2), DrupalKernel::findSitePath($request), $autoloader);
 $kernel = DrupalKernel::createFromRequest($request, $autoloader, 'prod')->boot();
 
 // Run the database dump command.
