@@ -14,7 +14,7 @@ class ElementValidationTest extends WebDriverTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['ajax_test', 'ajax_forms_test'];
+  protected static $modules = ['ajax_test', 'ajax_forms_test'];
 
   /**
    * {@inheritdoc}
@@ -44,7 +44,7 @@ class ElementValidationTest extends WebDriverTestBase {
     $this->assertNotNull($placeholder_text, 'A callback successfully echoed back a string.');
 
     $this->drupalGet('ajax_validation_test');
-    // Partialy complete the form with a number.
+    // Partially complete the form with a number.
     $page->fillField('drivernumber', '12345');
     $page->findField('spare_required_field')->focus();
 
