@@ -38,7 +38,7 @@ class UncaughtExceptionTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['error_service_test', 'error_test'];
+  protected static $modules = ['error_service_test', 'error_test'];
 
   /**
    * {@inheritdoc}
@@ -48,7 +48,7 @@ class UncaughtExceptionTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $settings_filename = $this->siteDirectory . '/settings.php';
@@ -115,7 +115,7 @@ class UncaughtExceptionTest extends BrowserTestBase {
       '%function' => 'Drupal\error_test\Controller\ErrorTestController->Drupal\error_test\Controller\{closure}()',
     ];
     $this->drupalGet('error-test/generate-fatals');
-    $this->assertResponse(500, 'Received expected HTTP status code.');
+    $this->assertResponse(500);
     $message = new FormattableMarkup('%type: @message in %function (line ', $fatal_error);
     $this->assertRaw((string) $message);
     $this->assertRaw('<pre class="backtrace">');
@@ -237,6 +237,7 @@ class UncaughtExceptionTest extends BrowserTestBase {
       case 'mysql':
         $this->expectedExceptionMessage = $incorrect_username;
         break;
+
       default:
         // We can not carry out this test.
         $this->pass('Unable to run \Drupal\system\Tests\System\UncaughtExceptionTest::testLostDatabaseConnection for this database type.');
@@ -279,13 +280,13 @@ class UncaughtExceptionTest extends BrowserTestBase {
 
     // Find fatal error logged to the error.log
     $errors = file(\Drupal::root() . '/' . $this->siteDirectory . '/error.log');
-    $this->assertIdentical(count($errors), 8, 'The error + the error that the logging service is broken has been written to the error log.');
-    $this->assertTrue(strpos($errors[0], 'Failed to log error') !== FALSE, 'The error handling logs when an error could not be logged to the logger.');
+    $this->assertCount(8, $errors, 'The error + the error that the logging service is broken has been written to the error log.');
+    $this->assertStringContainsString('Failed to log error', $errors[0], 'The error handling logs when an error could not be logged to the logger.');
 
     $expected_path = \Drupal::root() . '/core/modules/system/tests/modules/error_service_test/src/MonkeysInTheControlRoom.php';
     $expected_line = 59;
     $expected_entry = "Failed to log error: Exception: Deforestation in Drupal\\error_service_test\\MonkeysInTheControlRoom->handle() (line ${expected_line} of ${expected_path})";
-    $this->assert(strpos($errors[0], $expected_entry) !== FALSE, 'Original error logged to the PHP error log when an exception is thrown by a logger');
+    $this->assertStringContainsString($expected_entry, $errors[0], 'Original error logged to the PHP error log when an exception is thrown by a logger');
 
     // The exception is expected. Do not interpret it as a test failure. Not
     // using File API; a potential error must trigger a PHP warning.
@@ -303,9 +304,7 @@ class UncaughtExceptionTest extends BrowserTestBase {
    */
   protected function assertErrorLogged($error_message) {
     $error_log_filename = DRUPAL_ROOT . '/' . $this->siteDirectory . '/error.log';
-    if (!file_exists($error_log_filename)) {
-      $this->fail('No error logged yet.');
-    }
+    $this->assertFileExists($error_log_filename);
 
     $content = file_get_contents($error_log_filename);
     $rows = explode(PHP_EOL, $content);
@@ -334,7 +333,7 @@ class UncaughtExceptionTest extends BrowserTestBase {
   protected function assertNoErrorsLogged() {
     // Since PHP only creates the error.log file when an actual error is
     // triggered, it is sufficient to check whether the file exists.
-    $this->assertFalse(file_exists(DRUPAL_ROOT . '/' . $this->siteDirectory . '/error.log'), 'PHP error.log is empty.');
+    $this->assertFileNotExists(DRUPAL_ROOT . '/' . $this->siteDirectory . '/error.log');
   }
 
   /**
@@ -373,14 +372,14 @@ class UncaughtExceptionTest extends BrowserTestBase {
    * {@inheritdoc}
    */
   protected function assertText($text) {
-    $this->assertContains($text, $this->response);
+    $this->assertStringContainsString($text, $this->response);
   }
 
   /**
    * {@inheritdoc}
    */
   protected function assertNoText($text) {
-    $this->assertNotContains($text, $this->response);
+    $this->assertStringNotContainsString($text, $this->response);
   }
 
   /**
