@@ -3,7 +3,7 @@
 namespace Drupal\FunctionalTests\Installer;
 
 /**
- * Tests the installer when a config_directory has already been set up.
+ * Tests installation when a config_sync_directory exists and is set up.
  *
  * @group Installer
  */
@@ -39,7 +39,7 @@ class InstallerExistingConfigDirectoryTest extends InstallerTestBase {
    */
   public function testInstaller() {
     $this->assertUrl('user/1');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertEqual($this->expectedFilePerms, fileperms($this->siteDirectory . '/config_read_only'));
     $this->assertEqual([], glob($this->siteDirectory . '/config_read_only/*'), 'The sync directory is empty after install because it is read-only.');
   }
