@@ -23,7 +23,7 @@ class LibraryDiscoveryIntegrationTest extends KernelTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->container->get('theme_installer')->install(['test_theme', 'classy']);
@@ -37,7 +37,7 @@ class LibraryDiscoveryIntegrationTest extends KernelTestBase {
     // Activate test_theme and verify that the library 'kitten' is added using
     // hook_library_info_alter().
     $this->activateTheme('test_theme');
-    $this->assertTrue($this->libraryDiscovery->getLibraryByName('test_theme', 'kitten'));
+    $this->assertNotEmpty($this->libraryDiscovery->getLibraryByName('test_theme', 'kitten'));
 
     // Now make classy the active theme and assert that library is not added.
     $this->activateTheme('classy');
@@ -57,7 +57,7 @@ class LibraryDiscoveryIntegrationTest extends KernelTestBase {
     $this->assertAssetInLibrary('core/themes/classy/css/components/dialog.css', 'classy', 'dialog', 'css');
 
     // Confirmatory assert on core library to be removed.
-    $this->assertTrue($this->libraryDiscovery->getLibraryByName('core', 'drupal.progress'), 'Confirmatory test on "core/drupal.progress"');
+    $this->assertNotEmpty($this->libraryDiscovery->getLibraryByName('core', 'drupal.progress'), 'Confirmatory test on "core/drupal.progress"');
 
     // Activate test theme that defines libraries overrides.
     $this->activateTheme('test_theme');
