@@ -20,12 +20,12 @@ class CacheContextOptimizationTest extends KernelTestBase {
    *
    * @var string[]
    */
-  public static $modules = ['user', 'system'];
+  protected static $modules = ['user', 'system'];
 
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->installEntitySchema('user');
     $this->installConfig(['user']);
