@@ -13,7 +13,7 @@ class CaseSensitivityTest extends DatabaseTestBase {
    * Tests BINARY collation in MySQL.
    */
   public function testCaseSensitiveInsert() {
-    $num_records_before = db_query('SELECT COUNT(*) FROM {test}')->fetchField();
+    $num_records_before = $this->connection->query('SELECT COUNT(*) FROM {test}')->fetchField();
 
     $this->connection->insert('test')
       ->fields([
@@ -24,9 +24,9 @@ class CaseSensitivityTest extends DatabaseTestBase {
       ])
       ->execute();
 
-    $num_records_after = db_query('SELECT COUNT(*) FROM {test}')->fetchField();
+    $num_records_after = $this->connection->query('SELECT COUNT(*) FROM {test}')->fetchField();
     $this->assertSame($num_records_before + 1, (int) $num_records_after, 'Record inserts correctly.');
-    $saved_age = db_query('SELECT age FROM {test} WHERE name = :name', [':name' => 'john'])->fetchField();
+    $saved_age = $this->connection->query('SELECT age FROM {test} WHERE name = :name', [':name' => 'john'])->fetchField();
     $this->assertIdentical($saved_age, '2', 'Can retrieve after inserting.');
   }
 
