@@ -127,32 +127,20 @@ class UpdateTest extends DatabaseTestBase {
     $this->assertIdentical($num_rows, 5, 'Correctly returned 5 affected rows.');
   }
 
-  /**
-   * Confirm that we can update the primary key of a record successfully.
-   */
-  public function testPrimaryKeyUpdate() {
-    $num_updated = $this->connection->update('test')
-      ->fields(['id' => 42, 'name' => 'John'])
-      ->condition('id', 1)
-      ->execute();
-    $this->assertIdentical($num_updated, 1, 'Updated 1 record.');
-
-    $saved_name = $this->connection->query('SELECT name FROM {test} WHERE id = :id', [':id' => 42])->fetchField();
-    $this->assertIdentical($saved_name, 'John', 'Updated primary key successfully.');
-  }
-
   /**
    * Confirm that we can update values in a column with special name.
    */
   public function testSpecialColumnUpdate() {
-    $num_updated = $this->connection->update('test_special_columns')
-      ->fields(['offset' => 'New offset value'])
+    $num_updated = $this->connection->update('select')
+      ->fields([
+        'update' => 'New update value',
+      ])
       ->condition('id', 1)
       ->execute();
     $this->assertIdentical($num_updated, 1, 'Updated 1 special column record.');
 
-    $saved_value = $this->connection->query('SELECT "offset" FROM {test_special_columns} WHERE id = :id', [':id' => 1])->fetchField();
-    $this->assertIdentical($saved_value, 'New offset value', 'Updated special column name value successfully.');
+    $saved_value = $this->connection->query('SELECT [update] FROM {select} WHERE id = :id', [':id' => 1])->fetchField();
+    $this->assertEquals('New update value', $saved_value);
   }
 
 }
