@@ -18,7 +18,7 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
    *
    * @var array
    */
-  public static $modules = [];
+  protected static $modules = [];
 
   /**
    * The entity_test storage to create the test entities.
@@ -34,10 +34,10 @@ class EntityQueryAggregateTest extends EntityKernelTestBase {
    */
   protected $queryResult;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
-    $this->entityStorage = $this->entityManager->getStorage('entity_test');
+    $this->entityStorage = $this->entityTypeManager->getStorage('entity_test');
 
     // Add some fieldapi fields to be used in the test.
     for ($i = 1; $i <= 2; $i++) {
