@@ -6,7 +6,6 @@ use Drupal\Component\FileCache\ApcuFileCacheBackend;
 use Drupal\Component\FileCache\FileCache;
 use Drupal\Component\FileCache\FileCacheFactory;
 use Drupal\Component\Utility\Html;
-use Drupal\Component\Render\FormattableMarkup;
 use Drupal\Core\Config\Development\ConfigSchemaChecker;
 use Drupal\Core\Database\Database;
 use Drupal\Core\DependencyInjection\ContainerBuilder;
@@ -19,9 +18,10 @@ use Drupal\Core\Site\Settings;
 use Drupal\Core\Test\TestDatabase;
 use Drupal\Tests\AssertHelperTrait;
 use Drupal\Tests\ConfigTestTrait;
-use Drupal\Tests\PhpunitCompatibilityTrait;
 use Drupal\Tests\RandomGeneratorTrait;
 use Drupal\Tests\TestRequirementsTrait;
+use Drupal\Tests\Traits\PHPUnit8Warnings;
+use Drupal\TestTools\Comparator\MarkupInterfaceComparator;
 use PHPUnit\Framework\Exception;
 use PHPUnit\Framework\TestCase;
 use Symfony\Component\DependencyInjection\Reference;
@@ -80,7 +80,7 @@ abstract class KernelTestBase extends TestCase implements ServiceProviderInterfa
   use RandomGeneratorTrait;
   use ConfigTestTrait;
   use TestRequirementsTrait;
-  use PhpunitCompatibilityTrait;
+  use PHPUnit8Warnings;
 
   /**
    * {@inheritdoc}
@@ -164,17 +164,12 @@ abstract class KernelTestBase extends TestCase implements ServiceProviderInterfa
    * it extends, and so on up the class hierarchy. It is not necessary to
    * include modules in your list that a parent class has already declared.
    *
-   * The Path Alias module is always installed because the functionality has
-   * moved from core to a required module in Drupal 8.8.0. If a kernel test
-   * requires path alias functionality it is recommended to add the module to
-   * the test's own $modules property for Drupal 9 compatibility.
-   *
    * @see \Drupal\Tests\KernelTestBase::enableModules()
    * @see \Drupal\Tests\KernelTestBase::bootKernel()
    *
    * @var array
    */
-  protected static $modules = ['path_alias'];
+  protected static $modules = [];
 
   /**
    * The virtual filesystem root directory.
@@ -237,6 +232,9 @@ abstract class KernelTestBase extends TestCase implements ServiceProviderInterfa
   protected function setUp() {
     parent::setUp();
 
+    // Allow tests to compare MarkupInterface objects via assertEquals().
+    $this->registerComparator(new MarkupInterfaceComparator());
+
     $this->root = static::getDrupalRoot();
     $this->initFileCache();
     $this->bootEnvironment();
@@ -274,9 +272,6 @@ abstract class KernelTestBase extends TestCase implements ServiceProviderInterfa
     $settings = [
       'hash_salt' => get_class($this),
       'file_public_path' => $this->siteDirectory . '/files',
-      // Skip the "path_alias" schema check for kernel tests, since they do not
-      // rely on the full schema being installed.
-      'system.path_alias_schema_check' => FALSE,
       // Disable Twig template caching/dumping.
       'twig_cache' => FALSE,
       // @see \Drupal\KernelTests\KernelTestBase::register()
@@ -362,8 +357,10 @@ abstract class KernelTestBase extends TestCase implements ServiceProviderInterfa
 
     // Ensure database tasks have been run.
     require_once __DIR__ . '/../../../includes/install.inc';
-    $connection = Database::getConnection();
-    $errors = db_installer_object($connection->driver())->runTasks();
+    $connection_info = Database::getConnectionInfo();
+    $driver = $connection_info['default']['driver'];
+    $namespace = $connection_info['default']['namespace'] ?? NULL;
+    $errors = db_installer_object($driver, $namespace)->runTasks();
     if (!empty($errors)) {
       $this->fail('Failed to run installer database tasks: ' . implode(', ', $errors));
     }
@@ -714,11 +711,6 @@ abstract class KernelTestBase extends TestCase implements ServiceProviderInterfa
     foreach ($tables as $table) {
       $schema = drupal_get_module_schema($module, $table);
       if (empty($schema)) {
-        // BC layer to avoid some contrib tests to fail.
-        if ($module == 'system') {
-          @trigger_error('Special handling of system module schemas in \Drupal\KernelTests\KernelTestBase::installSchema has been deprecated in Drupal 8.7.x, remove any calls to this method that use invalid schema names. See https://www.drupal.org/node/3003360.', E_USER_DEPRECATED);
-          continue;
-        }
         throw new \LogicException("$module module does not define a schema for table '$table'.");
       }
       $this->container->get('database')->schema()->createTable($table, $schema);
@@ -742,21 +734,8 @@ abstract class KernelTestBase extends TestCase implements ServiceProviderInterfa
     if ($storage instanceof SqlEntityStorageInterface) {
       $tables = $storage->getTableMapping()->getTableNames();
       $db_schema = $this->container->get('database')->schema();
-      $all_tables_exist = TRUE;
       foreach ($tables as $table) {
-        if (!$db_schema->tableExists($table)) {
-          $this->fail(new FormattableMarkup('Installed entity type table for the %entity_type entity type: %table', [
-            '%entity_type' => $entity_type_id,
-            '%table' => $table,
-          ]));
-          $all_tables_exist = FALSE;
-        }
-      }
-      if ($all_tables_exist) {
-        $this->pass(new FormattableMarkup('Installed entity type tables for the %entity_type entity type: %tables', [
-          '%entity_type' => $entity_type_id,
-          '%tables' => '{' . implode('}, {', $tables) . '}',
-        ]));
+        $this->assertTrue($db_schema->tableExists($table), "The entity type table '$table' for the entity type '$entity_type_id' should exist.");
       }
     }
   }
@@ -786,12 +765,6 @@ abstract class KernelTestBase extends TestCase implements ServiceProviderInterfa
    *   If a module is not enabled after enabling it.
    */
   protected function enableModules(array $modules) {
-    $trace = debug_backtrace(DEBUG_BACKTRACE_IGNORE_ARGS);
-    if ($trace[1]['function'] === 'setUp') {
-      trigger_error('KernelTestBase::enableModules() should not be called from setUp(). Use the $modules property instead.', E_USER_DEPRECATED);
-    }
-    unset($trace);
-
     // Perform an ExtensionDiscovery scan as this function may receive a
     // profile that is not the current profile, and we don't yet have a cached
     // way to receive inactive profile information.
@@ -918,10 +891,6 @@ abstract class KernelTestBase extends TestCase implements ServiceProviderInterfa
    *   \Drupal\Core\Site\Settings::get() to perform custom merges.
    */
   protected function setSetting($name, $value) {
-    if ($name === 'install_profile') {
-      @trigger_error('Use \Drupal\KernelTests\KernelTestBase::setInstallProfile() to set the install profile in kernel tests. See https://www.drupal.org/node/2538996', E_USER_DEPRECATED);
-      $this->setInstallProfile($value);
-    }
     $settings = Settings::getInstance() ? Settings::getAll() : [];
     $settings[$name] = $value;
     new Settings($settings);
@@ -1006,87 +975,6 @@ abstract class KernelTestBase extends TestCase implements ServiceProviderInterfa
     ]);
   }
 
-  /**
-   * Returns whether the current test method is running in a separate process.
-   *
-   * Note that KernelTestBase will run in a separate process by default.
-   *
-   * @return bool
-   *
-   * @see \Drupal\KernelTests\KernelTestBase::$runTestInSeparateProcess
-   * @see https://github.com/sebastianbergmann/phpunit/pull/1350
-   *
-   * @deprecated in drupal:8.4.0 and is removed from drupal:9.0.0.
-   *   KernelTestBase tests are always run in isolated processes.
-   */
-  protected function isTestInIsolation() {
-    @trigger_error(__CLASS__ . '::' . __FUNCTION__ . '() is deprecated in Drupal 8.4.x, for removal before the Drupal 9.0.0 release. KernelTestBase tests are always run in isolated processes.', E_USER_DEPRECATED);
-    return function_exists('__phpunit_run_isolated_test');
-  }
-
-  /**
-   * BC: Automatically resolve former KernelTestBase class properties.
-   *
-   * Test authors should follow the provided instructions and adjust their tests
-   * accordingly.
-   *
-   * @deprecated in drupal:8.0.0 and is removed from drupal:9.0.0.
-   */
-  public function __get($name) {
-    if (in_array($name, [
-      'public_files_directory',
-      'private_files_directory',
-      'temp_files_directory',
-      'translation_files_directory',
-    ])) {
-      // @comment it in again.
-      trigger_error(sprintf("KernelTestBase::\$%s no longer exists. Use the regular API method to retrieve it instead (e.g., Settings).", $name), E_USER_DEPRECATED);
-      switch ($name) {
-        case 'public_files_directory':
-          return Settings::get('file_public_path', \Drupal::service('site.path') . '/files');
-
-        case 'private_files_directory':
-          return Settings::get('file_private_path');
-
-        case 'temp_files_directory':
-          return \Drupal::service('file_system')->getTempDirectory();
-
-        case 'translation_files_directory':
-          return Settings::get('file_public_path', \Drupal::service('site.path') . '/translations');
-      }
-    }
-
-    if ($name === 'configDirectories') {
-      trigger_error(sprintf("KernelTestBase::\$%s no longer exists. Use Settings::get('config_sync_directory') directly instead.", $name), E_USER_DEPRECATED);
-      return [
-        CONFIG_SYNC_DIRECTORY => Settings::get('config_sync_directory'),
-      ];
-    }
-
-    $denied = [
-      // @see \Drupal\simpletest\TestBase
-      'testId',
-      'timeLimit',
-      'results',
-      'assertions',
-      'skipClasses',
-      'verbose',
-      'verboseId',
-      'verboseClassName',
-      'verboseDirectory',
-      'verboseDirectoryUrl',
-      'dieOnFail',
-      'kernel',
-      // @see \Drupal\simpletest\TestBase::prepareEnvironment()
-      'generatedTestFiles',
-      // Properties from the old KernelTestBase class that has been removed.
-      'keyValueFactory',
-    ];
-    if (in_array($name, $denied) || strpos($name, 'original') === 0) {
-      throw new \RuntimeException(sprintf('TestBase::$%s property no longer exists', $name));
-    }
-  }
-
   /**
    * Prevents serializing any properties.
    *
