@@ -35,7 +35,7 @@ class CsrfAccessCheckTest extends UnitTestCase {
    */
   protected $routeMatch;
 
-  protected function setUp() {
+  protected function setUp(): void {
     $this->csrfToken = $this->getMockBuilder('Drupal\Core\Access\CsrfTokenGenerator')
       ->disableOriginalConstructor()
       ->getMock();
