@@ -3,6 +3,7 @@
 namespace Drupal\Tests\Core\Database\Stub;
 
 use Drupal\Core\Database\Connection;
+use Drupal\Core\Database\Log;
 use Drupal\Core\Database\StatementEmpty;
 
 /**
@@ -20,17 +21,32 @@ class StubConnection extends Connection {
    */
   public $driver = 'stub';
 
+  /**
+   * Constructs a Connection object.
+   *
+   * @param \PDO $connection
+   *   An object of the PDO class representing a database connection.
+   * @param array $connection_options
+   *   An array of options for the connection.
+   * @param string[]|null $identifier_quotes
+   *   The identifier quote characters. Defaults to an empty strings.
+   */
+  public function __construct(\PDO $connection, array $connection_options, $identifier_quotes = ['', '']) {
+    $this->identifierQuotes = $identifier_quotes;
+    parent::__construct($connection, $connection_options);
+  }
+
   /**
    * {@inheritdoc}
    */
-  public function queryRange($query, $from, $count, array $args = array(), array $options = array()) {
+  public function queryRange($query, $from, $count, array $args = [], array $options = []) {
     return new StatementEmpty();
   }
 
   /**
    * {@inheritdoc}
    */
-  public function queryTemporary($query, array $args = array(), array $options = array()) {
+  public function queryTemporary($query, array $args = [], array $options = []) {
     return '';
   }
 
@@ -69,4 +85,14 @@ class StubConnection extends Connection {
     return 0;
   }
 
+  /**
+   * Helper method to test database classes are not included in backtraces.
+   *
+   * @return array
+   *   The caller stack entry.
+   */
+  public function testLogCaller() {
+    return (new Log())->findCaller();
+  }
+
 }
