@@ -79,7 +79,8 @@ class RequestFormatRouteFilterTest extends UnitTestCase {
     $request = Request::create('test?_format=xml', 'GET');
     $request->setRequestFormat('xml');
     $route_filter = new RequestFormatRouteFilter();
-    $this->setExpectedException(NotAcceptableHttpException::class, 'No route found for the specified format xml.');
+    $this->expectException(NotAcceptableHttpException::class);
+    $this->expectExceptionMessage('No route found for the specified format xml.');
     $route_filter->filter($collection, $request);
   }
 
@@ -87,7 +88,8 @@ class RequestFormatRouteFilterTest extends UnitTestCase {
    * @covers ::filter
    */
   public function testNoRouteFoundWhenNoRequestFormatAndSingleRouteWithMultipleFormats() {
-    $this->setExpectedException(NotAcceptableHttpException::class, 'No route found for the specified format html.');
+    $this->expectException(NotAcceptableHttpException::class);
+    $this->expectExceptionMessage('No route found for the specified format html.');
 
     $url = $this->prophesize(GeneratedUrl::class);
     $url_assembler = $this->prophesize(UnroutedUrlAssemblerInterface::class);
