@@ -32,7 +32,7 @@ class NegotiationMiddlewareTest extends UnitTestCase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->app = $this->prophesize(HttpKernelInterface::class);
