@@ -56,7 +56,7 @@ class RecursiveContextualValidatorTest extends UnitTestCase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $cache_backend = new NullBackend('cache');
